from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.base_item_kind import BaseItemKind
from ...models.search_hint_result import SearchHintResult
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    search_term: str,
    include_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    exclude_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    media_types: Union[Unset, None, List[str]] = UNSET,
    parent_id: Union[Unset, None, str] = UNSET,
    is_movie: Union[Unset, None, bool] = UNSET,
    is_series: Union[Unset, None, bool] = UNSET,
    is_news: Union[Unset, None, bool] = UNSET,
    is_kids: Union[Unset, None, bool] = UNSET,
    is_sports: Union[Unset, None, bool] = UNSET,
    include_people: Union[Unset, None, bool] = True,
    include_media: Union[Unset, None, bool] = True,
    include_genres: Union[Unset, None, bool] = True,
    include_studios: Union[Unset, None, bool] = True,
    include_artists: Union[Unset, None, bool] = True,
) -> Dict[str, Any]:
    pass

    params: Dict[str, Any] = {}
    params["startIndex"] = start_index

    params["limit"] = limit

    params["userId"] = user_id

    params["searchTerm"] = search_term

    json_include_item_types: Union[Unset, None, List[str]] = UNSET
    if not isinstance(include_item_types, Unset):
        if include_item_types is None:
            json_include_item_types = None
        else:
            json_include_item_types = []
            for include_item_types_item_data in include_item_types:
                include_item_types_item = include_item_types_item_data.value

                json_include_item_types.append(include_item_types_item)

    params["includeItemTypes"] = json_include_item_types

    json_exclude_item_types: Union[Unset, None, List[str]] = UNSET
    if not isinstance(exclude_item_types, Unset):
        if exclude_item_types is None:
            json_exclude_item_types = None
        else:
            json_exclude_item_types = []
            for exclude_item_types_item_data in exclude_item_types:
                exclude_item_types_item = exclude_item_types_item_data.value

                json_exclude_item_types.append(exclude_item_types_item)

    params["excludeItemTypes"] = json_exclude_item_types

    json_media_types: Union[Unset, None, List[str]] = UNSET
    if not isinstance(media_types, Unset):
        if media_types is None:
            json_media_types = None
        else:
            json_media_types = media_types

    params["mediaTypes"] = json_media_types

    params["parentId"] = parent_id

    params["isMovie"] = is_movie

    params["isSeries"] = is_series

    params["isNews"] = is_news

    params["isKids"] = is_kids

    params["isSports"] = is_sports

    params["includePeople"] = include_people

    params["includeMedia"] = include_media

    params["includeGenres"] = include_genres

    params["includeStudios"] = include_studios

    params["includeArtists"] = include_artists

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": "/Search/Hints",
        "params": params,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, SearchHintResult]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = SearchHintResult.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = cast(Any, None)
        return response_401
    if response.status_code == HTTPStatus.FORBIDDEN:
        response_403 = cast(Any, None)
        return response_403
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, SearchHintResult]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    search_term: str,
    include_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    exclude_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    media_types: Union[Unset, None, List[str]] = UNSET,
    parent_id: Union[Unset, None, str] = UNSET,
    is_movie: Union[Unset, None, bool] = UNSET,
    is_series: Union[Unset, None, bool] = UNSET,
    is_news: Union[Unset, None, bool] = UNSET,
    is_kids: Union[Unset, None, bool] = UNSET,
    is_sports: Union[Unset, None, bool] = UNSET,
    include_people: Union[Unset, None, bool] = True,
    include_media: Union[Unset, None, bool] = True,
    include_genres: Union[Unset, None, bool] = True,
    include_studios: Union[Unset, None, bool] = True,
    include_artists: Union[Unset, None, bool] = True,
) -> Response[Union[Any, SearchHintResult]]:
    """Gets the search hint result.

    Args:
        start_index (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        user_id (Union[Unset, None, str]):
        search_term (str):
        include_item_types (Union[Unset, None, List[BaseItemKind]]):
        exclude_item_types (Union[Unset, None, List[BaseItemKind]]):
        media_types (Union[Unset, None, List[str]]):
        parent_id (Union[Unset, None, str]):
        is_movie (Union[Unset, None, bool]):
        is_series (Union[Unset, None, bool]):
        is_news (Union[Unset, None, bool]):
        is_kids (Union[Unset, None, bool]):
        is_sports (Union[Unset, None, bool]):
        include_people (Union[Unset, None, bool]):  Default: True.
        include_media (Union[Unset, None, bool]):  Default: True.
        include_genres (Union[Unset, None, bool]):  Default: True.
        include_studios (Union[Unset, None, bool]):  Default: True.
        include_artists (Union[Unset, None, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, SearchHintResult]]
    """

    kwargs = _get_kwargs(
        start_index=start_index,
        limit=limit,
        user_id=user_id,
        search_term=search_term,
        include_item_types=include_item_types,
        exclude_item_types=exclude_item_types,
        media_types=media_types,
        parent_id=parent_id,
        is_movie=is_movie,
        is_series=is_series,
        is_news=is_news,
        is_kids=is_kids,
        is_sports=is_sports,
        include_people=include_people,
        include_media=include_media,
        include_genres=include_genres,
        include_studios=include_studios,
        include_artists=include_artists,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    search_term: str,
    include_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    exclude_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    media_types: Union[Unset, None, List[str]] = UNSET,
    parent_id: Union[Unset, None, str] = UNSET,
    is_movie: Union[Unset, None, bool] = UNSET,
    is_series: Union[Unset, None, bool] = UNSET,
    is_news: Union[Unset, None, bool] = UNSET,
    is_kids: Union[Unset, None, bool] = UNSET,
    is_sports: Union[Unset, None, bool] = UNSET,
    include_people: Union[Unset, None, bool] = True,
    include_media: Union[Unset, None, bool] = True,
    include_genres: Union[Unset, None, bool] = True,
    include_studios: Union[Unset, None, bool] = True,
    include_artists: Union[Unset, None, bool] = True,
) -> Optional[Union[Any, SearchHintResult]]:
    """Gets the search hint result.

    Args:
        start_index (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        user_id (Union[Unset, None, str]):
        search_term (str):
        include_item_types (Union[Unset, None, List[BaseItemKind]]):
        exclude_item_types (Union[Unset, None, List[BaseItemKind]]):
        media_types (Union[Unset, None, List[str]]):
        parent_id (Union[Unset, None, str]):
        is_movie (Union[Unset, None, bool]):
        is_series (Union[Unset, None, bool]):
        is_news (Union[Unset, None, bool]):
        is_kids (Union[Unset, None, bool]):
        is_sports (Union[Unset, None, bool]):
        include_people (Union[Unset, None, bool]):  Default: True.
        include_media (Union[Unset, None, bool]):  Default: True.
        include_genres (Union[Unset, None, bool]):  Default: True.
        include_studios (Union[Unset, None, bool]):  Default: True.
        include_artists (Union[Unset, None, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, SearchHintResult]
    """

    return sync_detailed(
        client=client,
        start_index=start_index,
        limit=limit,
        user_id=user_id,
        search_term=search_term,
        include_item_types=include_item_types,
        exclude_item_types=exclude_item_types,
        media_types=media_types,
        parent_id=parent_id,
        is_movie=is_movie,
        is_series=is_series,
        is_news=is_news,
        is_kids=is_kids,
        is_sports=is_sports,
        include_people=include_people,
        include_media=include_media,
        include_genres=include_genres,
        include_studios=include_studios,
        include_artists=include_artists,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    search_term: str,
    include_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    exclude_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    media_types: Union[Unset, None, List[str]] = UNSET,
    parent_id: Union[Unset, None, str] = UNSET,
    is_movie: Union[Unset, None, bool] = UNSET,
    is_series: Union[Unset, None, bool] = UNSET,
    is_news: Union[Unset, None, bool] = UNSET,
    is_kids: Union[Unset, None, bool] = UNSET,
    is_sports: Union[Unset, None, bool] = UNSET,
    include_people: Union[Unset, None, bool] = True,
    include_media: Union[Unset, None, bool] = True,
    include_genres: Union[Unset, None, bool] = True,
    include_studios: Union[Unset, None, bool] = True,
    include_artists: Union[Unset, None, bool] = True,
) -> Response[Union[Any, SearchHintResult]]:
    """Gets the search hint result.

    Args:
        start_index (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        user_id (Union[Unset, None, str]):
        search_term (str):
        include_item_types (Union[Unset, None, List[BaseItemKind]]):
        exclude_item_types (Union[Unset, None, List[BaseItemKind]]):
        media_types (Union[Unset, None, List[str]]):
        parent_id (Union[Unset, None, str]):
        is_movie (Union[Unset, None, bool]):
        is_series (Union[Unset, None, bool]):
        is_news (Union[Unset, None, bool]):
        is_kids (Union[Unset, None, bool]):
        is_sports (Union[Unset, None, bool]):
        include_people (Union[Unset, None, bool]):  Default: True.
        include_media (Union[Unset, None, bool]):  Default: True.
        include_genres (Union[Unset, None, bool]):  Default: True.
        include_studios (Union[Unset, None, bool]):  Default: True.
        include_artists (Union[Unset, None, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, SearchHintResult]]
    """

    kwargs = _get_kwargs(
        start_index=start_index,
        limit=limit,
        user_id=user_id,
        search_term=search_term,
        include_item_types=include_item_types,
        exclude_item_types=exclude_item_types,
        media_types=media_types,
        parent_id=parent_id,
        is_movie=is_movie,
        is_series=is_series,
        is_news=is_news,
        is_kids=is_kids,
        is_sports=is_sports,
        include_people=include_people,
        include_media=include_media,
        include_genres=include_genres,
        include_studios=include_studios,
        include_artists=include_artists,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    search_term: str,
    include_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    exclude_item_types: Union[Unset, None, List[BaseItemKind]] = UNSET,
    media_types: Union[Unset, None, List[str]] = UNSET,
    parent_id: Union[Unset, None, str] = UNSET,
    is_movie: Union[Unset, None, bool] = UNSET,
    is_series: Union[Unset, None, bool] = UNSET,
    is_news: Union[Unset, None, bool] = UNSET,
    is_kids: Union[Unset, None, bool] = UNSET,
    is_sports: Union[Unset, None, bool] = UNSET,
    include_people: Union[Unset, None, bool] = True,
    include_media: Union[Unset, None, bool] = True,
    include_genres: Union[Unset, None, bool] = True,
    include_studios: Union[Unset, None, bool] = True,
    include_artists: Union[Unset, None, bool] = True,
) -> Optional[Union[Any, SearchHintResult]]:
    """Gets the search hint result.

    Args:
        start_index (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        user_id (Union[Unset, None, str]):
        search_term (str):
        include_item_types (Union[Unset, None, List[BaseItemKind]]):
        exclude_item_types (Union[Unset, None, List[BaseItemKind]]):
        media_types (Union[Unset, None, List[str]]):
        parent_id (Union[Unset, None, str]):
        is_movie (Union[Unset, None, bool]):
        is_series (Union[Unset, None, bool]):
        is_news (Union[Unset, None, bool]):
        is_kids (Union[Unset, None, bool]):
        is_sports (Union[Unset, None, bool]):
        include_people (Union[Unset, None, bool]):  Default: True.
        include_media (Union[Unset, None, bool]):  Default: True.
        include_genres (Union[Unset, None, bool]):  Default: True.
        include_studios (Union[Unset, None, bool]):  Default: True.
        include_artists (Union[Unset, None, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, SearchHintResult]
    """

    return (
        await asyncio_detailed(
            client=client,
            start_index=start_index,
            limit=limit,
            user_id=user_id,
            search_term=search_term,
            include_item_types=include_item_types,
            exclude_item_types=exclude_item_types,
            media_types=media_types,
            parent_id=parent_id,
            is_movie=is_movie,
            is_series=is_series,
            is_news=is_news,
            is_kids=is_kids,
            is_sports=is_sports,
            include_people=include_people,
            include_media=include_media,
            include_genres=include_genres,
            include_studios=include_studios,
            include_artists=include_artists,
        )
    ).parsed



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.media_stream_type import MediaStreamType
from ..models.subtitle_delivery_method import SubtitleDeliveryMethod
from ..types import UNSET, Unset

T = TypeVar("T", bound="MediaStream")


@_attrs_define
class MediaStream:
    """Class MediaStream.

    Attributes:
        codec (Union[Unset, None, str]): Gets or sets the codec.
        codec_tag (Union[Unset, None, str]): Gets or sets the codec tag.
        language (Union[Unset, None, str]): Gets or sets the language.
        color_range (Union[Unset, None, str]): Gets or sets the color range.
        color_space (Union[Unset, None, str]): Gets or sets the color space.
        color_transfer (Union[Unset, None, str]): Gets or sets the color transfer.
        color_primaries (Union[Unset, None, str]): Gets or sets the color primaries.
        dv_version_major (Union[Unset, None, int]): Gets or sets the Dolby Vision version major.
        dv_version_minor (Union[Unset, None, int]): Gets or sets the Dolby Vision version minor.
        dv_profile (Union[Unset, None, int]): Gets or sets the Dolby Vision profile.
        dv_level (Union[Unset, None, int]): Gets or sets the Dolby Vision level.
        rpu_present_flag (Union[Unset, None, int]): Gets or sets the Dolby Vision rpu present flag.
        el_present_flag (Union[Unset, None, int]): Gets or sets the Dolby Vision el present flag.
        bl_present_flag (Union[Unset, None, int]): Gets or sets the Dolby Vision bl present flag.
        dv_bl_signal_compatibility_id (Union[Unset, None, int]): Gets or sets the Dolby Vision bl signal compatibility
            id.
        comment (Union[Unset, None, str]): Gets or sets the comment.
        time_base (Union[Unset, None, str]): Gets or sets the time base.
        codec_time_base (Union[Unset, None, str]): Gets or sets the codec time base.
        title (Union[Unset, None, str]): Gets or sets the title.
        video_range (Union[Unset, None, str]): Gets the video range.
        video_range_type (Union[Unset, None, str]): Gets the video range type.
        video_do_vi_title (Union[Unset, None, str]): Gets the video dovi title.
        localized_undefined (Union[Unset, None, str]):
        localized_default (Union[Unset, None, str]):
        localized_forced (Union[Unset, None, str]):
        localized_external (Union[Unset, None, str]):
        display_title (Union[Unset, None, str]):
        nal_length_size (Union[Unset, None, str]):
        is_interlaced (Union[Unset, bool]): Gets or sets a value indicating whether this instance is interlaced.
        is_avc (Union[Unset, None, bool]):
        channel_layout (Union[Unset, None, str]): Gets or sets the channel layout.
        bit_rate (Union[Unset, None, int]): Gets or sets the bit rate.
        bit_depth (Union[Unset, None, int]): Gets or sets the bit depth.
        ref_frames (Union[Unset, None, int]): Gets or sets the reference frames.
        packet_length (Union[Unset, None, int]): Gets or sets the length of the packet.
        channels (Union[Unset, None, int]): Gets or sets the channels.
        sample_rate (Union[Unset, None, int]): Gets or sets the sample rate.
        is_default (Union[Unset, bool]): Gets or sets a value indicating whether this instance is default.
        is_forced (Union[Unset, bool]): Gets or sets a value indicating whether this instance is forced.
        height (Union[Unset, None, int]): Gets or sets the height.
        width (Union[Unset, None, int]): Gets or sets the width.
        average_frame_rate (Union[Unset, None, float]): Gets or sets the average frame rate.
        real_frame_rate (Union[Unset, None, float]): Gets or sets the real frame rate.
        profile (Union[Unset, None, str]): Gets or sets the profile.
        type (Union[Unset, MediaStreamType]): Enum MediaStreamType.
        aspect_ratio (Union[Unset, None, str]): Gets or sets the aspect ratio.
        index (Union[Unset, int]): Gets or sets the index.
        score (Union[Unset, None, int]): Gets or sets the score.
        is_external (Union[Unset, bool]): Gets or sets a value indicating whether this instance is external.
        delivery_method (Union[Unset, None, SubtitleDeliveryMethod]): Delivery method to use during playback of a
            specific subtitle format.
        delivery_url (Union[Unset, None, str]): Gets or sets the delivery URL.
        is_external_url (Union[Unset, None, bool]): Gets or sets a value indicating whether this instance is external
            URL.
        is_text_subtitle_stream (Union[Unset, bool]):
        supports_external_stream (Union[Unset, bool]): Gets or sets a value indicating whether [supports external
            stream].
        path (Union[Unset, None, str]): Gets or sets the filename.
        pixel_format (Union[Unset, None, str]): Gets or sets the pixel format.
        level (Union[Unset, None, float]): Gets or sets the level.
        is_anamorphic (Union[Unset, None, bool]): Gets or sets whether this instance is anamorphic.
    """

    codec: Union[Unset, None, str] = UNSET
    codec_tag: Union[Unset, None, str] = UNSET
    language: Union[Unset, None, str] = UNSET
    color_range: Union[Unset, None, str] = UNSET
    color_space: Union[Unset, None, str] = UNSET
    color_transfer: Union[Unset, None, str] = UNSET
    color_primaries: Union[Unset, None, str] = UNSET
    dv_version_major: Union[Unset, None, int] = UNSET
    dv_version_minor: Union[Unset, None, int] = UNSET
    dv_profile: Union[Unset, None, int] = UNSET
    dv_level: Union[Unset, None, int] = UNSET
    rpu_present_flag: Union[Unset, None, int] = UNSET
    el_present_flag: Union[Unset, None, int] = UNSET
    bl_present_flag: Union[Unset, None, int] = UNSET
    dv_bl_signal_compatibility_id: Union[Unset, None, int] = UNSET
    comment: Union[Unset, None, str] = UNSET
    time_base: Union[Unset, None, str] = UNSET
    codec_time_base: Union[Unset, None, str] = UNSET
    title: Union[Unset, None, str] = UNSET
    video_range: Union[Unset, None, str] = UNSET
    video_range_type: Union[Unset, None, str] = UNSET
    video_do_vi_title: Union[Unset, None, str] = UNSET
    localized_undefined: Union[Unset, None, str] = UNSET
    localized_default: Union[Unset, None, str] = UNSET
    localized_forced: Union[Unset, None, str] = UNSET
    localized_external: Union[Unset, None, str] = UNSET
    display_title: Union[Unset, None, str] = UNSET
    nal_length_size: Union[Unset, None, str] = UNSET
    is_interlaced: Union[Unset, bool] = UNSET
    is_avc: Union[Unset, None, bool] = UNSET
    channel_layout: Union[Unset, None, str] = UNSET
    bit_rate: Union[Unset, None, int] = UNSET
    bit_depth: Union[Unset, None, int] = UNSET
    ref_frames: Union[Unset, None, int] = UNSET
    packet_length: Union[Unset, None, int] = UNSET
    channels: Union[Unset, None, int] = UNSET
    sample_rate: Union[Unset, None, int] = UNSET
    is_default: Union[Unset, bool] = UNSET
    is_forced: Union[Unset, bool] = UNSET
    height: Union[Unset, None, int] = UNSET
    width: Union[Unset, None, int] = UNSET
    average_frame_rate: Union[Unset, None, float] = UNSET
    real_frame_rate: Union[Unset, None, float] = UNSET
    profile: Union[Unset, None, str] = UNSET
    type: Union[Unset, MediaStreamType] = UNSET
    aspect_ratio: Union[Unset, None, str] = UNSET
    index: Union[Unset, int] = UNSET
    score: Union[Unset, None, int] = UNSET
    is_external: Union[Unset, bool] = UNSET
    delivery_method: Union[Unset, None, SubtitleDeliveryMethod] = UNSET
    delivery_url: Union[Unset, None, str] = UNSET
    is_external_url: Union[Unset, None, bool] = UNSET
    is_text_subtitle_stream: Union[Unset, bool] = UNSET
    supports_external_stream: Union[Unset, bool] = UNSET
    path: Union[Unset, None, str] = UNSET
    pixel_format: Union[Unset, None, str] = UNSET
    level: Union[Unset, None, float] = UNSET
    is_anamorphic: Union[Unset, None, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        codec = self.codec
        codec_tag = self.codec_tag
        language = self.language
        color_range = self.color_range
        color_space = self.color_space
        color_transfer = self.color_transfer
        color_primaries = self.color_primaries
        dv_version_major = self.dv_version_major
        dv_version_minor = self.dv_version_minor
        dv_profile = self.dv_profile
        dv_level = self.dv_level
        rpu_present_flag = self.rpu_present_flag
        el_present_flag = self.el_present_flag
        bl_present_flag = self.bl_present_flag
        dv_bl_signal_compatibility_id = self.dv_bl_signal_compatibility_id
        comment = self.comment
        time_base = self.time_base
        codec_time_base = self.codec_time_base
        title = self.title
        video_range = self.video_range
        video_range_type = self.video_range_type
        video_do_vi_title = self.video_do_vi_title
        localized_undefined = self.localized_undefined
        localized_default = self.localized_default
        localized_forced = self.localized_forced
        localized_external = self.localized_external
        display_title = self.display_title
        nal_length_size = self.nal_length_size
        is_interlaced = self.is_interlaced
        is_avc = self.is_avc
        channel_layout = self.channel_layout
        bit_rate = self.bit_rate
        bit_depth = self.bit_depth
        ref_frames = self.ref_frames
        packet_length = self.packet_length
        channels = self.channels
        sample_rate = self.sample_rate
        is_default = self.is_default
        is_forced = self.is_forced
        height = self.height
        width = self.width
        average_frame_rate = self.average_frame_rate
        real_frame_rate = self.real_frame_rate
        profile = self.profile
        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        aspect_ratio = self.aspect_ratio
        index = self.index
        score = self.score
        is_external = self.is_external
        delivery_method: Union[Unset, None, str] = UNSET
        if not isinstance(self.delivery_method, Unset):
            delivery_method = self.delivery_method.value if self.delivery_method else None

        delivery_url = self.delivery_url
        is_external_url = self.is_external_url
        is_text_subtitle_stream = self.is_text_subtitle_stream
        supports_external_stream = self.supports_external_stream
        path = self.path
        pixel_format = self.pixel_format
        level = self.level
        is_anamorphic = self.is_anamorphic

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if codec is not UNSET:
            field_dict["Codec"] = codec
        if codec_tag is not UNSET:
            field_dict["CodecTag"] = codec_tag
        if language is not UNSET:
            field_dict["Language"] = language
        if color_range is not UNSET:
            field_dict["ColorRange"] = color_range
        if color_space is not UNSET:
            field_dict["ColorSpace"] = color_space
        if color_transfer is not UNSET:
            field_dict["ColorTransfer"] = color_transfer
        if color_primaries is not UNSET:
            field_dict["ColorPrimaries"] = color_primaries
        if dv_version_major is not UNSET:
            field_dict["DvVersionMajor"] = dv_version_major
        if dv_version_minor is not UNSET:
            field_dict["DvVersionMinor"] = dv_version_minor
        if dv_profile is not UNSET:
            field_dict["DvProfile"] = dv_profile
        if dv_level is not UNSET:
            field_dict["DvLevel"] = dv_level
        if rpu_present_flag is not UNSET:
            field_dict["RpuPresentFlag"] = rpu_present_flag
        if el_present_flag is not UNSET:
            field_dict["ElPresentFlag"] = el_present_flag
        if bl_present_flag is not UNSET:
            field_dict["BlPresentFlag"] = bl_present_flag
        if dv_bl_signal_compatibility_id is not UNSET:
            field_dict["DvBlSignalCompatibilityId"] = dv_bl_signal_compatibility_id
        if comment is not UNSET:
            field_dict["Comment"] = comment
        if time_base is not UNSET:
            field_dict["TimeBase"] = time_base
        if codec_time_base is not UNSET:
            field_dict["CodecTimeBase"] = codec_time_base
        if title is not UNSET:
            field_dict["Title"] = title
        if video_range is not UNSET:
            field_dict["VideoRange"] = video_range
        if video_range_type is not UNSET:
            field_dict["VideoRangeType"] = video_range_type
        if video_do_vi_title is not UNSET:
            field_dict["VideoDoViTitle"] = video_do_vi_title
        if localized_undefined is not UNSET:
            field_dict["LocalizedUndefined"] = localized_undefined
        if localized_default is not UNSET:
            field_dict["LocalizedDefault"] = localized_default
        if localized_forced is not UNSET:
            field_dict["LocalizedForced"] = localized_forced
        if localized_external is not UNSET:
            field_dict["LocalizedExternal"] = localized_external
        if display_title is not UNSET:
            field_dict["DisplayTitle"] = display_title
        if nal_length_size is not UNSET:
            field_dict["NalLengthSize"] = nal_length_size
        if is_interlaced is not UNSET:
            field_dict["IsInterlaced"] = is_interlaced
        if is_avc is not UNSET:
            field_dict["IsAVC"] = is_avc
        if channel_layout is not UNSET:
            field_dict["ChannelLayout"] = channel_layout
        if bit_rate is not UNSET:
            field_dict["BitRate"] = bit_rate
        if bit_depth is not UNSET:
            field_dict["BitDepth"] = bit_depth
        if ref_frames is not UNSET:
            field_dict["RefFrames"] = ref_frames
        if packet_length is not UNSET:
            field_dict["PacketLength"] = packet_length
        if channels is not UNSET:
            field_dict["Channels"] = channels
        if sample_rate is not UNSET:
            field_dict["SampleRate"] = sample_rate
        if is_default is not UNSET:
            field_dict["IsDefault"] = is_default
        if is_forced is not UNSET:
            field_dict["IsForced"] = is_forced
        if height is not UNSET:
            field_dict["Height"] = height
        if width is not UNSET:
            field_dict["Width"] = width
        if average_frame_rate is not UNSET:
            field_dict["AverageFrameRate"] = average_frame_rate
        if real_frame_rate is not UNSET:
            field_dict["RealFrameRate"] = real_frame_rate
        if profile is not UNSET:
            field_dict["Profile"] = profile
        if type is not UNSET:
            field_dict["Type"] = type
        if aspect_ratio is not UNSET:
            field_dict["AspectRatio"] = aspect_ratio
        if index is not UNSET:
            field_dict["Index"] = index
        if score is not UNSET:
            field_dict["Score"] = score
        if is_external is not UNSET:
            field_dict["IsExternal"] = is_external
        if delivery_method is not UNSET:
            field_dict["DeliveryMethod"] = delivery_method
        if delivery_url is not UNSET:
            field_dict["DeliveryUrl"] = delivery_url
        if is_external_url is not UNSET:
            field_dict["IsExternalUrl"] = is_external_url
        if is_text_subtitle_stream is not UNSET:
            field_dict["IsTextSubtitleStream"] = is_text_subtitle_stream
        if supports_external_stream is not UNSET:
            field_dict["SupportsExternalStream"] = supports_external_stream
        if path is not UNSET:
            field_dict["Path"] = path
        if pixel_format is not UNSET:
            field_dict["PixelFormat"] = pixel_format
        if level is not UNSET:
            field_dict["Level"] = level
        if is_anamorphic is not UNSET:
            field_dict["IsAnamorphic"] = is_anamorphic

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        codec = d.pop("Codec", UNSET)

        codec_tag = d.pop("CodecTag", UNSET)

        language = d.pop("Language", UNSET)

        color_range = d.pop("ColorRange", UNSET)

        color_space = d.pop("ColorSpace", UNSET)

        color_transfer = d.pop("ColorTransfer", UNSET)

        color_primaries = d.pop("ColorPrimaries", UNSET)

        dv_version_major = d.pop("DvVersionMajor", UNSET)

        dv_version_minor = d.pop("DvVersionMinor", UNSET)

        dv_profile = d.pop("DvProfile", UNSET)

        dv_level = d.pop("DvLevel", UNSET)

        rpu_present_flag = d.pop("RpuPresentFlag", UNSET)

        el_present_flag = d.pop("ElPresentFlag", UNSET)

        bl_present_flag = d.pop("BlPresentFlag", UNSET)

        dv_bl_signal_compatibility_id = d.pop("DvBlSignalCompatibilityId", UNSET)

        comment = d.pop("Comment", UNSET)

        time_base = d.pop("TimeBase", UNSET)

        codec_time_base = d.pop("CodecTimeBase", UNSET)

        title = d.pop("Title", UNSET)

        video_range = d.pop("VideoRange", UNSET)

        video_range_type = d.pop("VideoRangeType", UNSET)

        video_do_vi_title = d.pop("VideoDoViTitle", UNSET)

        localized_undefined = d.pop("LocalizedUndefined", UNSET)

        localized_default = d.pop("LocalizedDefault", UNSET)

        localized_forced = d.pop("LocalizedForced", UNSET)

        localized_external = d.pop("LocalizedExternal", UNSET)

        display_title = d.pop("DisplayTitle", UNSET)

        nal_length_size = d.pop("NalLengthSize", UNSET)

        is_interlaced = d.pop("IsInterlaced", UNSET)

        is_avc = d.pop("IsAVC", UNSET)

        channel_layout = d.pop("ChannelLayout", UNSET)

        bit_rate = d.pop("BitRate", UNSET)

        bit_depth = d.pop("BitDepth", UNSET)

        ref_frames = d.pop("RefFrames", UNSET)

        packet_length = d.pop("PacketLength", UNSET)

        channels = d.pop("Channels", UNSET)

        sample_rate = d.pop("SampleRate", UNSET)

        is_default = d.pop("IsDefault", UNSET)

        is_forced = d.pop("IsForced", UNSET)

        height = d.pop("Height", UNSET)

        width = d.pop("Width", UNSET)

        average_frame_rate = d.pop("AverageFrameRate", UNSET)

        real_frame_rate = d.pop("RealFrameRate", UNSET)

        profile = d.pop("Profile", UNSET)

        _type = d.pop("Type", UNSET)
        type: Union[Unset, MediaStreamType]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = MediaStreamType(_type)

        aspect_ratio = d.pop("AspectRatio", UNSET)

        index = d.pop("Index", UNSET)

        score = d.pop("Score", UNSET)

        is_external = d.pop("IsExternal", UNSET)

        _delivery_method = d.pop("DeliveryMethod", UNSET)
        delivery_method: Union[Unset, None, SubtitleDeliveryMethod]
        if _delivery_method is None:
            delivery_method = None
        elif isinstance(_delivery_method, Unset):
            delivery_method = UNSET
        else:
            delivery_method = SubtitleDeliveryMethod(_delivery_method)

        delivery_url = d.pop("DeliveryUrl", UNSET)

        is_external_url = d.pop("IsExternalUrl", UNSET)

        is_text_subtitle_stream = d.pop("IsTextSubtitleStream", UNSET)

        supports_external_stream = d.pop("SupportsExternalStream", UNSET)

        path = d.pop("Path", UNSET)

        pixel_format = d.pop("PixelFormat", UNSET)

        level = d.pop("Level", UNSET)

        is_anamorphic = d.pop("IsAnamorphic", UNSET)

        media_stream = cls(
            codec=codec,
            codec_tag=codec_tag,
            language=language,
            color_range=color_range,
            color_space=color_space,
            color_transfer=color_transfer,
            color_primaries=color_primaries,
            dv_version_major=dv_version_major,
            dv_version_minor=dv_version_minor,
            dv_profile=dv_profile,
            dv_level=dv_level,
            rpu_present_flag=rpu_present_flag,
            el_present_flag=el_present_flag,
            bl_present_flag=bl_present_flag,
            dv_bl_signal_compatibility_id=dv_bl_signal_compatibility_id,
            comment=comment,
            time_base=time_base,
            codec_time_base=codec_time_base,
            title=title,
            video_range=video_range,
            video_range_type=video_range_type,
            video_do_vi_title=video_do_vi_title,
            localized_undefined=localized_undefined,
            localized_default=localized_default,
            localized_forced=localized_forced,
            localized_external=localized_external,
            display_title=display_title,
            nal_length_size=nal_length_size,
            is_interlaced=is_interlaced,
            is_avc=is_avc,
            channel_layout=channel_layout,
            bit_rate=bit_rate,
            bit_depth=bit_depth,
            ref_frames=ref_frames,
            packet_length=packet_length,
            channels=channels,
            sample_rate=sample_rate,
            is_default=is_default,
            is_forced=is_forced,
            height=height,
            width=width,
            average_frame_rate=average_frame_rate,
            real_frame_rate=real_frame_rate,
            profile=profile,
            type=type,
            aspect_ratio=aspect_ratio,
            index=index,
            score=score,
            is_external=is_external,
            delivery_method=delivery_method,
            delivery_url=delivery_url,
            is_external_url=is_external_url,
            is_text_subtitle_stream=is_text_subtitle_stream,
            supports_external_stream=supports_external_stream,
            path=path,
            pixel_format=pixel_format,
            level=level,
            is_anamorphic=is_anamorphic,
        )

        return media_stream



from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.scroll_direction import ScrollDirection
from ..models.sort_order import SortOrder
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.display_preferences_dto_custom_prefs import DisplayPreferencesDtoCustomPrefs


T = TypeVar("T", bound="DisplayPreferencesDto")


@_attrs_define
class DisplayPreferencesDto:
    """Defines the display preferences for any item that supports them (usually Folders).

    Attributes:
        id (Union[Unset, None, str]): Gets or sets the user id.
        view_type (Union[Unset, None, str]): Gets or sets the type of the view.
        sort_by (Union[Unset, None, str]): Gets or sets the sort by.
        index_by (Union[Unset, None, str]): Gets or sets the index by.
        remember_indexing (Union[Unset, bool]): Gets or sets a value indicating whether [remember indexing].
        primary_image_height (Union[Unset, int]): Gets or sets the height of the primary image.
        primary_image_width (Union[Unset, int]): Gets or sets the width of the primary image.
        custom_prefs (Union[Unset, DisplayPreferencesDtoCustomPrefs]): Gets or sets the custom prefs.
        scroll_direction (Union[Unset, ScrollDirection]): An enum representing the axis that should be scrolled.
        show_backdrop (Union[Unset, bool]): Gets or sets a value indicating whether to show backdrops on this item.
        remember_sorting (Union[Unset, bool]): Gets or sets a value indicating whether [remember sorting].
        sort_order (Union[Unset, SortOrder]): An enum representing the sorting order.
        show_sidebar (Union[Unset, bool]): Gets or sets a value indicating whether [show sidebar].
        client (Union[Unset, None, str]): Gets or sets the client.
    """

    id: Union[Unset, None, str] = UNSET
    view_type: Union[Unset, None, str] = UNSET
    sort_by: Union[Unset, None, str] = UNSET
    index_by: Union[Unset, None, str] = UNSET
    remember_indexing: Union[Unset, bool] = UNSET
    primary_image_height: Union[Unset, int] = UNSET
    primary_image_width: Union[Unset, int] = UNSET
    custom_prefs: Union[Unset, "DisplayPreferencesDtoCustomPrefs"] = UNSET
    scroll_direction: Union[Unset, ScrollDirection] = UNSET
    show_backdrop: Union[Unset, bool] = UNSET
    remember_sorting: Union[Unset, bool] = UNSET
    sort_order: Union[Unset, SortOrder] = UNSET
    show_sidebar: Union[Unset, bool] = UNSET
    client: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        view_type = self.view_type
        sort_by = self.sort_by
        index_by = self.index_by
        remember_indexing = self.remember_indexing
        primary_image_height = self.primary_image_height
        primary_image_width = self.primary_image_width
        custom_prefs: Union[Unset, Dict[str, Any]] = UNSET
        if not isinstance(self.custom_prefs, Unset):
            custom_prefs = self.custom_prefs.to_dict()

        scroll_direction: Union[Unset, str] = UNSET
        if not isinstance(self.scroll_direction, Unset):
            scroll_direction = self.scroll_direction.value

        show_backdrop = self.show_backdrop
        remember_sorting = self.remember_sorting
        sort_order: Union[Unset, str] = UNSET
        if not isinstance(self.sort_order, Unset):
            sort_order = self.sort_order.value

        show_sidebar = self.show_sidebar
        client = self.client

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if id is not UNSET:
            field_dict["Id"] = id
        if view_type is not UNSET:
            field_dict["ViewType"] = view_type
        if sort_by is not UNSET:
            field_dict["SortBy"] = sort_by
        if index_by is not UNSET:
            field_dict["IndexBy"] = index_by
        if remember_indexing is not UNSET:
            field_dict["RememberIndexing"] = remember_indexing
        if primary_image_height is not UNSET:
            field_dict["PrimaryImageHeight"] = primary_image_height
        if primary_image_width is not UNSET:
            field_dict["PrimaryImageWidth"] = primary_image_width
        if custom_prefs is not UNSET:
            field_dict["CustomPrefs"] = custom_prefs
        if scroll_direction is not UNSET:
            field_dict["ScrollDirection"] = scroll_direction
        if show_backdrop is not UNSET:
            field_dict["ShowBackdrop"] = show_backdrop
        if remember_sorting is not UNSET:
            field_dict["RememberSorting"] = remember_sorting
        if sort_order is not UNSET:
            field_dict["SortOrder"] = sort_order
        if show_sidebar is not UNSET:
            field_dict["ShowSidebar"] = show_sidebar
        if client is not UNSET:
            field_dict["Client"] = client

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.display_preferences_dto_custom_prefs import DisplayPreferencesDtoCustomPrefs

        d = src_dict.copy()
        id = d.pop("Id", UNSET)

        view_type = d.pop("ViewType", UNSET)

        sort_by = d.pop("SortBy", UNSET)

        index_by = d.pop("IndexBy", UNSET)

        remember_indexing = d.pop("RememberIndexing", UNSET)

        primary_image_height = d.pop("PrimaryImageHeight", UNSET)

        primary_image_width = d.pop("PrimaryImageWidth", UNSET)

        _custom_prefs = d.pop("CustomPrefs", UNSET)
        custom_prefs: Union[Unset, DisplayPreferencesDtoCustomPrefs]
        if isinstance(_custom_prefs, Unset):
            custom_prefs = UNSET
        else:
            custom_prefs = DisplayPreferencesDtoCustomPrefs.from_dict(_custom_prefs)

        _scroll_direction = d.pop("ScrollDirection", UNSET)
        scroll_direction: Union[Unset, ScrollDirection]
        if isinstance(_scroll_direction, Unset):
            scroll_direction = UNSET
        else:
            scroll_direction = ScrollDirection(_scroll_direction)

        show_backdrop = d.pop("ShowBackdrop", UNSET)

        remember_sorting = d.pop("RememberSorting", UNSET)

        _sort_order = d.pop("SortOrder", UNSET)
        sort_order: Union[Unset, SortOrder]
        if isinstance(_sort_order, Unset):
            sort_order = UNSET
        else:
            sort_order = SortOrder(_sort_order)

        show_sidebar = d.pop("ShowSidebar", UNSET)

        client = d.pop("Client", UNSET)

        display_preferences_dto = cls(
            id=id,
            view_type=view_type,
            sort_by=sort_by,
            index_by=index_by,
            remember_indexing=remember_indexing,
            primary_image_height=primary_image_height,
            primary_image_width=primary_image_width,
            custom_prefs=custom_prefs,
            scroll_direction=scroll_direction,
            show_backdrop=show_backdrop,
            remember_sorting=remember_sorting,
            sort_order=sort_order,
            show_sidebar=show_sidebar,
            client=client,
        )

        return display_preferences_dto



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.notification_option import NotificationOption


T = TypeVar("T", bound="NotificationOptions")


@_attrs_define
class NotificationOptions:
    """
    Attributes:
        options (Union[Unset, None, List['NotificationOption']]):
    """

    options: Union[Unset, None, List["NotificationOption"]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        options: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.options, Unset):
            if self.options is None:
                options = None
            else:
                options = []
                for options_item_data in self.options:
                    options_item = options_item_data.to_dict()

                    options.append(options_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if options is not UNSET:
            field_dict["Options"] = options

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.notification_option import NotificationOption

        d = src_dict.copy()
        options = []
        _options = d.pop("Options", UNSET)
        for options_item_data in _options or []:
            options_item = NotificationOption.from_dict(options_item_data)

            options.append(options_item)

        notification_options = cls(
            options=options,
        )

        return notification_options



from enum import Enum


class PluginStatus(str, Enum):
    ACTIVE = "Active"
    DELETED = "Deleted"
    DISABLED = "Disabled"
    MALFUNCTIONED = "Malfunctioned"
    NOTSUPPORTED = "NotSupported"
    RESTART = "Restart"
    SUPERCEDED = "Superceded"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class LocationType(str, Enum):
    FILESYSTEM = "FileSystem"
    OFFLINE = "Offline"
    REMOTE = "Remote"
    VIRTUAL = "Virtual"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.dlna_profile_type import DlnaProfileType
from ..models.encoding_context import EncodingContext
from ..models.transcode_seek_info import TranscodeSeekInfo
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.profile_condition import ProfileCondition


T = TypeVar("T", bound="TranscodingProfile")


@_attrs_define
class TranscodingProfile:
    """
    Attributes:
        container (Union[Unset, str]):
        type (Union[Unset, DlnaProfileType]):
        video_codec (Union[Unset, str]):
        audio_codec (Union[Unset, str]):
        protocol (Union[Unset, str]):
        estimate_content_length (Union[Unset, bool]):
        enable_mpegts_m2_ts_mode (Union[Unset, bool]):
        transcode_seek_info (Union[Unset, TranscodeSeekInfo]):  Default: TranscodeSeekInfo.AUTO.
        copy_timestamps (Union[Unset, bool]):
        context (Union[Unset, EncodingContext]):  Default: EncodingContext.STREAMING.
        enable_subtitles_in_manifest (Union[Unset, bool]):
        max_audio_channels (Union[Unset, None, str]):
        min_segments (Union[Unset, int]):
        segment_length (Union[Unset, int]):
        break_on_non_key_frames (Union[Unset, bool]):
        conditions (Union[Unset, List['ProfileCondition']]):
    """

    container: Union[Unset, str] = UNSET
    type: Union[Unset, DlnaProfileType] = UNSET
    video_codec: Union[Unset, str] = UNSET
    audio_codec: Union[Unset, str] = UNSET
    protocol: Union[Unset, str] = UNSET
    estimate_content_length: Union[Unset, bool] = False
    enable_mpegts_m2_ts_mode: Union[Unset, bool] = False
    transcode_seek_info: Union[Unset, TranscodeSeekInfo] = TranscodeSeekInfo.AUTO
    copy_timestamps: Union[Unset, bool] = False
    context: Union[Unset, EncodingContext] = EncodingContext.STREAMING
    enable_subtitles_in_manifest: Union[Unset, bool] = False
    max_audio_channels: Union[Unset, None, str] = UNSET
    min_segments: Union[Unset, int] = 0
    segment_length: Union[Unset, int] = 0
    break_on_non_key_frames: Union[Unset, bool] = False
    conditions: Union[Unset, List["ProfileCondition"]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        container = self.container
        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        video_codec = self.video_codec
        audio_codec = self.audio_codec
        protocol = self.protocol
        estimate_content_length = self.estimate_content_length
        enable_mpegts_m2_ts_mode = self.enable_mpegts_m2_ts_mode
        transcode_seek_info: Union[Unset, str] = UNSET
        if not isinstance(self.transcode_seek_info, Unset):
            transcode_seek_info = self.transcode_seek_info.value

        copy_timestamps = self.copy_timestamps
        context: Union[Unset, str] = UNSET
        if not isinstance(self.context, Unset):
            context = self.context.value

        enable_subtitles_in_manifest = self.enable_subtitles_in_manifest
        max_audio_channels = self.max_audio_channels
        min_segments = self.min_segments
        segment_length = self.segment_length
        break_on_non_key_frames = self.break_on_non_key_frames
        conditions: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.conditions, Unset):
            conditions = []
            for conditions_item_data in self.conditions:
                conditions_item = conditions_item_data.to_dict()

                conditions.append(conditions_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if container is not UNSET:
            field_dict["Container"] = container
        if type is not UNSET:
            field_dict["Type"] = type
        if video_codec is not UNSET:
            field_dict["VideoCodec"] = video_codec
        if audio_codec is not UNSET:
            field_dict["AudioCodec"] = audio_codec
        if protocol is not UNSET:
            field_dict["Protocol"] = protocol
        if estimate_content_length is not UNSET:
            field_dict["EstimateContentLength"] = estimate_content_length
        if enable_mpegts_m2_ts_mode is not UNSET:
            field_dict["EnableMpegtsM2TsMode"] = enable_mpegts_m2_ts_mode
        if transcode_seek_info is not UNSET:
            field_dict["TranscodeSeekInfo"] = transcode_seek_info
        if copy_timestamps is not UNSET:
            field_dict["CopyTimestamps"] = copy_timestamps
        if context is not UNSET:
            field_dict["Context"] = context
        if enable_subtitles_in_manifest is not UNSET:
            field_dict["EnableSubtitlesInManifest"] = enable_subtitles_in_manifest
        if max_audio_channels is not UNSET:
            field_dict["MaxAudioChannels"] = max_audio_channels
        if min_segments is not UNSET:
            field_dict["MinSegments"] = min_segments
        if segment_length is not UNSET:
            field_dict["SegmentLength"] = segment_length
        if break_on_non_key_frames is not UNSET:
            field_dict["BreakOnNonKeyFrames"] = break_on_non_key_frames
        if conditions is not UNSET:
            field_dict["Conditions"] = conditions

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.profile_condition import ProfileCondition

        d = src_dict.copy()
        container = d.pop("Container", UNSET)

        _type = d.pop("Type", UNSET)
        type: Union[Unset, DlnaProfileType]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = DlnaProfileType(_type)

        video_codec = d.pop("VideoCodec", UNSET)

        audio_codec = d.pop("AudioCodec", UNSET)

        protocol = d.pop("Protocol", UNSET)

        estimate_content_length = d.pop("EstimateContentLength", UNSET)

        enable_mpegts_m2_ts_mode = d.pop("EnableMpegtsM2TsMode", UNSET)

        _transcode_seek_info = d.pop("TranscodeSeekInfo", UNSET)
        transcode_seek_info: Union[Unset, TranscodeSeekInfo]
        if isinstance(_transcode_seek_info, Unset):
            transcode_seek_info = UNSET
        else:
            transcode_seek_info = TranscodeSeekInfo(_transcode_seek_info)

        copy_timestamps = d.pop("CopyTimestamps", UNSET)

        _context = d.pop("Context", UNSET)
        context: Union[Unset, EncodingContext]
        if isinstance(_context, Unset):
            context = UNSET
        else:
            context = EncodingContext(_context)

        enable_subtitles_in_manifest = d.pop("EnableSubtitlesInManifest", UNSET)

        max_audio_channels = d.pop("MaxAudioChannels", UNSET)

        min_segments = d.pop("MinSegments", UNSET)

        segment_length = d.pop("SegmentLength", UNSET)

        break_on_non_key_frames = d.pop("BreakOnNonKeyFrames", UNSET)

        conditions = []
        _conditions = d.pop("Conditions", UNSET)
        for conditions_item_data in _conditions or []:
            conditions_item = ProfileCondition.from_dict(conditions_item_data)

            conditions.append(conditions_item)

        transcoding_profile = cls(
            container=container,
            type=type,
            video_codec=video_codec,
            audio_codec=audio_codec,
            protocol=protocol,
            estimate_content_length=estimate_content_length,
            enable_mpegts_m2_ts_mode=enable_mpegts_m2_ts_mode,
            transcode_seek_info=transcode_seek_info,
            copy_timestamps=copy_timestamps,
            context=context,
            enable_subtitles_in_manifest=enable_subtitles_in_manifest,
            max_audio_channels=max_audio_channels,
            min_segments=min_segments,
            segment_length=segment_length,
            break_on_non_key_frames=break_on_non_key_frames,
            conditions=conditions,
        )

        return transcoding_profile



from typing import TYPE_CHECKING, Any, Dict, Type, TypeVar

from attrs import define as _attrs_define

if TYPE_CHECKING:
    from ..models.media_path_info import MediaPathInfo


T = TypeVar("T", bound="UpdateMediaPathRequestDto")


@_attrs_define
class UpdateMediaPathRequestDto:
    """Update library options dto.

    Attributes:
        name (str): Gets or sets the library name.
        path_info (MediaPathInfo):
    """

    name: str
    path_info: "MediaPathInfo"

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        path_info = self.path_info.to_dict()

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "Name": name,
                "PathInfo": path_info,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.media_path_info import MediaPathInfo

        d = src_dict.copy()
        name = d.pop("Name")

        path_info = MediaPathInfo.from_dict(d.pop("PathInfo"))

        update_media_path_request_dto = cls(
            name=name,
            path_info=path_info,
        )

        return update_media_path_request_dto



import datetime
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.base_item_dto_query_result import BaseItemDtoQueryResult
from ...models.image_type import ImageType
from ...models.item_fields import ItemFields
from ...models.sort_order import SortOrder
from ...types import UNSET, Response, Unset


def _get_kwargs(
    *,
    channel_ids: Union[Unset, None, List[str]] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    min_start_date: Union[Unset, None, datetime.datetime] = UNSET,
    has_aired: Union[Unset, None, bool] = UNSET,
    is_airing: Union[Unset, None, bool] = UNSET,
    max_start_date: Union[Unset, None, datetime.datetime] = UNSET,
    min_end_date: Union[Unset, None, datetime.datetime] = UNSET,
    max_end_date: Union[Unset, None, datetime.datetime] = UNSET,
    is_movie: Union[Unset, None, bool] = UNSET,
    is_series: Union[Unset, None, bool] = UNSET,
    is_news: Union[Unset, None, bool] = UNSET,
    is_kids: Union[Unset, None, bool] = UNSET,
    is_sports: Union[Unset, None, bool] = UNSET,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    sort_by: Union[Unset, None, List[str]] = UNSET,
    sort_order: Union[Unset, None, List[SortOrder]] = UNSET,
    genres: Union[Unset, None, List[str]] = UNSET,
    genre_ids: Union[Unset, None, List[str]] = UNSET,
    enable_images: Union[Unset, None, bool] = UNSET,
    image_type_limit: Union[Unset, None, int] = UNSET,
    enable_image_types: Union[Unset, None, List[ImageType]] = UNSET,
    enable_user_data: Union[Unset, None, bool] = UNSET,
    series_timer_id: Union[Unset, None, str] = UNSET,
    library_series_id: Union[Unset, None, str] = UNSET,
    fields: Union[Unset, None, List[ItemFields]] = UNSET,
    enable_total_record_count: Union[Unset, None, bool] = True,
) -> Dict[str, Any]:
    pass

    params: Dict[str, Any] = {}
    json_channel_ids: Union[Unset, None, List[str]] = UNSET
    if not isinstance(channel_ids, Unset):
        if channel_ids is None:
            json_channel_ids = None
        else:
            json_channel_ids = channel_ids

    params["channelIds"] = json_channel_ids

    params["userId"] = user_id

    json_min_start_date: Union[Unset, None, str] = UNSET
    if not isinstance(min_start_date, Unset):
        json_min_start_date = min_start_date.isoformat() if min_start_date else None

    params["minStartDate"] = json_min_start_date

    params["hasAired"] = has_aired

    params["isAiring"] = is_airing

    json_max_start_date: Union[Unset, None, str] = UNSET
    if not isinstance(max_start_date, Unset):
        json_max_start_date = max_start_date.isoformat() if max_start_date else None

    params["maxStartDate"] = json_max_start_date

    json_min_end_date: Union[Unset, None, str] = UNSET
    if not isinstance(min_end_date, Unset):
        json_min_end_date = min_end_date.isoformat() if min_end_date else None

    params["minEndDate"] = json_min_end_date

    json_max_end_date: Union[Unset, None, str] = UNSET
    if not isinstance(max_end_date, Unset):
        json_max_end_date = max_end_date.isoformat() if max_end_date else None

    params["maxEndDate"] = json_max_end_date

    params["isMovie"] = is_movie

    params["isSeries"] = is_series

    params["isNews"] = is_news

    params["isKids"] = is_kids

    params["isSports"] = is_sports

    params["startIndex"] = start_index

    params["limit"] = limit

    json_sort_by: Union[Unset, None, List[str]] = UNSET
    if not isinstance(sort_by, Unset):
        if sort_by is None:
            json_sort_by = None
        else:
            json_sort_by = sort_by

    params["sortBy"] = json_sort_by

    json_sort_order: Union[Unset, None, List[str]] = UNSET
    if not isinstance(sort_order, Unset):
        if sort_order is None:
            json_sort_order = None
        else:
            json_sort_order = []
            for sort_order_item_data in sort_order:
                sort_order_item = sort_order_item_data.value

                json_sort_order.append(sort_order_item)

    params["sortOrder"] = json_sort_order

    json_genres: Union[Unset, None, List[str]] = UNSET
    if not isinstance(genres, Unset):
        if genres is None:
            json_genres = None
        else:
            json_genres = genres

    params["genres"] = json_genres

    json_genre_ids: Union[Unset, None, List[str]] = UNSET
    if not isinstance(genre_ids, Unset):
        if genre_ids is None:
            json_genre_ids = None
        else:
            json_genre_ids = genre_ids

    params["genreIds"] = json_genre_ids

    params["enableImages"] = enable_images

    params["imageTypeLimit"] = image_type_limit

    json_enable_image_types: Union[Unset, None, List[str]] = UNSET
    if not isinstance(enable_image_types, Unset):
        if enable_image_types is None:
            json_enable_image_types = None
        else:
            json_enable_image_types = []
            for enable_image_types_item_data in enable_image_types:
                enable_image_types_item = enable_image_types_item_data.value

                json_enable_image_types.append(enable_image_types_item)

    params["enableImageTypes"] = json_enable_image_types

    params["enableUserData"] = enable_user_data

    params["seriesTimerId"] = series_timer_id

    params["librarySeriesId"] = library_series_id

    json_fields: Union[Unset, None, List[str]] = UNSET
    if not isinstance(fields, Unset):
        if fields is None:
            json_fields = None
        else:
            json_fields = []
            for fields_item_data in fields:
                fields_item = fields_item_data.value

                json_fields.append(fields_item)

    params["fields"] = json_fields

    params["enableTotalRecordCount"] = enable_total_record_count

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": "/LiveTv/Programs",
        "params": params,
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, BaseItemDtoQueryResult]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = BaseItemDtoQueryResult.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = cast(Any, None)
        return response_401
    if response.status_code == HTTPStatus.FORBIDDEN:
        response_403 = cast(Any, None)
        return response_403
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, BaseItemDtoQueryResult]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
    channel_ids: Union[Unset, None, List[str]] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    min_start_date: Union[Unset, None, datetime.datetime] = UNSET,
    has_aired: Union[Unset, None, bool] = UNSET,
    is_airing: Union[Unset, None, bool] = UNSET,
    max_start_date: Union[Unset, None, datetime.datetime] = UNSET,
    min_end_date: Union[Unset, None, datetime.datetime] = UNSET,
    max_end_date: Union[Unset, None, datetime.datetime] = UNSET,
    is_movie: Union[Unset, None, bool] = UNSET,
    is_series: Union[Unset, None, bool] = UNSET,
    is_news: Union[Unset, None, bool] = UNSET,
    is_kids: Union[Unset, None, bool] = UNSET,
    is_sports: Union[Unset, None, bool] = UNSET,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    sort_by: Union[Unset, None, List[str]] = UNSET,
    sort_order: Union[Unset, None, List[SortOrder]] = UNSET,
    genres: Union[Unset, None, List[str]] = UNSET,
    genre_ids: Union[Unset, None, List[str]] = UNSET,
    enable_images: Union[Unset, None, bool] = UNSET,
    image_type_limit: Union[Unset, None, int] = UNSET,
    enable_image_types: Union[Unset, None, List[ImageType]] = UNSET,
    enable_user_data: Union[Unset, None, bool] = UNSET,
    series_timer_id: Union[Unset, None, str] = UNSET,
    library_series_id: Union[Unset, None, str] = UNSET,
    fields: Union[Unset, None, List[ItemFields]] = UNSET,
    enable_total_record_count: Union[Unset, None, bool] = True,
) -> Response[Union[Any, BaseItemDtoQueryResult]]:
    """Gets available live tv epgs.

    Args:
        channel_ids (Union[Unset, None, List[str]]):
        user_id (Union[Unset, None, str]):
        min_start_date (Union[Unset, None, datetime.datetime]):
        has_aired (Union[Unset, None, bool]):
        is_airing (Union[Unset, None, bool]):
        max_start_date (Union[Unset, None, datetime.datetime]):
        min_end_date (Union[Unset, None, datetime.datetime]):
        max_end_date (Union[Unset, None, datetime.datetime]):
        is_movie (Union[Unset, None, bool]):
        is_series (Union[Unset, None, bool]):
        is_news (Union[Unset, None, bool]):
        is_kids (Union[Unset, None, bool]):
        is_sports (Union[Unset, None, bool]):
        start_index (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        sort_by (Union[Unset, None, List[str]]):
        sort_order (Union[Unset, None, List[SortOrder]]):
        genres (Union[Unset, None, List[str]]):
        genre_ids (Union[Unset, None, List[str]]):
        enable_images (Union[Unset, None, bool]):
        image_type_limit (Union[Unset, None, int]):
        enable_image_types (Union[Unset, None, List[ImageType]]):
        enable_user_data (Union[Unset, None, bool]):
        series_timer_id (Union[Unset, None, str]):
        library_series_id (Union[Unset, None, str]):
        fields (Union[Unset, None, List[ItemFields]]):
        enable_total_record_count (Union[Unset, None, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, BaseItemDtoQueryResult]]
    """

    kwargs = _get_kwargs(
        channel_ids=channel_ids,
        user_id=user_id,
        min_start_date=min_start_date,
        has_aired=has_aired,
        is_airing=is_airing,
        max_start_date=max_start_date,
        min_end_date=min_end_date,
        max_end_date=max_end_date,
        is_movie=is_movie,
        is_series=is_series,
        is_news=is_news,
        is_kids=is_kids,
        is_sports=is_sports,
        start_index=start_index,
        limit=limit,
        sort_by=sort_by,
        sort_order=sort_order,
        genres=genres,
        genre_ids=genre_ids,
        enable_images=enable_images,
        image_type_limit=image_type_limit,
        enable_image_types=enable_image_types,
        enable_user_data=enable_user_data,
        series_timer_id=series_timer_id,
        library_series_id=library_series_id,
        fields=fields,
        enable_total_record_count=enable_total_record_count,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
    channel_ids: Union[Unset, None, List[str]] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    min_start_date: Union[Unset, None, datetime.datetime] = UNSET,
    has_aired: Union[Unset, None, bool] = UNSET,
    is_airing: Union[Unset, None, bool] = UNSET,
    max_start_date: Union[Unset, None, datetime.datetime] = UNSET,
    min_end_date: Union[Unset, None, datetime.datetime] = UNSET,
    max_end_date: Union[Unset, None, datetime.datetime] = UNSET,
    is_movie: Union[Unset, None, bool] = UNSET,
    is_series: Union[Unset, None, bool] = UNSET,
    is_news: Union[Unset, None, bool] = UNSET,
    is_kids: Union[Unset, None, bool] = UNSET,
    is_sports: Union[Unset, None, bool] = UNSET,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    sort_by: Union[Unset, None, List[str]] = UNSET,
    sort_order: Union[Unset, None, List[SortOrder]] = UNSET,
    genres: Union[Unset, None, List[str]] = UNSET,
    genre_ids: Union[Unset, None, List[str]] = UNSET,
    enable_images: Union[Unset, None, bool] = UNSET,
    image_type_limit: Union[Unset, None, int] = UNSET,
    enable_image_types: Union[Unset, None, List[ImageType]] = UNSET,
    enable_user_data: Union[Unset, None, bool] = UNSET,
    series_timer_id: Union[Unset, None, str] = UNSET,
    library_series_id: Union[Unset, None, str] = UNSET,
    fields: Union[Unset, None, List[ItemFields]] = UNSET,
    enable_total_record_count: Union[Unset, None, bool] = True,
) -> Optional[Union[Any, BaseItemDtoQueryResult]]:
    """Gets available live tv epgs.

    Args:
        channel_ids (Union[Unset, None, List[str]]):
        user_id (Union[Unset, None, str]):
        min_start_date (Union[Unset, None, datetime.datetime]):
        has_aired (Union[Unset, None, bool]):
        is_airing (Union[Unset, None, bool]):
        max_start_date (Union[Unset, None, datetime.datetime]):
        min_end_date (Union[Unset, None, datetime.datetime]):
        max_end_date (Union[Unset, None, datetime.datetime]):
        is_movie (Union[Unset, None, bool]):
        is_series (Union[Unset, None, bool]):
        is_news (Union[Unset, None, bool]):
        is_kids (Union[Unset, None, bool]):
        is_sports (Union[Unset, None, bool]):
        start_index (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        sort_by (Union[Unset, None, List[str]]):
        sort_order (Union[Unset, None, List[SortOrder]]):
        genres (Union[Unset, None, List[str]]):
        genre_ids (Union[Unset, None, List[str]]):
        enable_images (Union[Unset, None, bool]):
        image_type_limit (Union[Unset, None, int]):
        enable_image_types (Union[Unset, None, List[ImageType]]):
        enable_user_data (Union[Unset, None, bool]):
        series_timer_id (Union[Unset, None, str]):
        library_series_id (Union[Unset, None, str]):
        fields (Union[Unset, None, List[ItemFields]]):
        enable_total_record_count (Union[Unset, None, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, BaseItemDtoQueryResult]
    """

    return sync_detailed(
        client=client,
        channel_ids=channel_ids,
        user_id=user_id,
        min_start_date=min_start_date,
        has_aired=has_aired,
        is_airing=is_airing,
        max_start_date=max_start_date,
        min_end_date=min_end_date,
        max_end_date=max_end_date,
        is_movie=is_movie,
        is_series=is_series,
        is_news=is_news,
        is_kids=is_kids,
        is_sports=is_sports,
        start_index=start_index,
        limit=limit,
        sort_by=sort_by,
        sort_order=sort_order,
        genres=genres,
        genre_ids=genre_ids,
        enable_images=enable_images,
        image_type_limit=image_type_limit,
        enable_image_types=enable_image_types,
        enable_user_data=enable_user_data,
        series_timer_id=series_timer_id,
        library_series_id=library_series_id,
        fields=fields,
        enable_total_record_count=enable_total_record_count,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
    channel_ids: Union[Unset, None, List[str]] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    min_start_date: Union[Unset, None, datetime.datetime] = UNSET,
    has_aired: Union[Unset, None, bool] = UNSET,
    is_airing: Union[Unset, None, bool] = UNSET,
    max_start_date: Union[Unset, None, datetime.datetime] = UNSET,
    min_end_date: Union[Unset, None, datetime.datetime] = UNSET,
    max_end_date: Union[Unset, None, datetime.datetime] = UNSET,
    is_movie: Union[Unset, None, bool] = UNSET,
    is_series: Union[Unset, None, bool] = UNSET,
    is_news: Union[Unset, None, bool] = UNSET,
    is_kids: Union[Unset, None, bool] = UNSET,
    is_sports: Union[Unset, None, bool] = UNSET,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    sort_by: Union[Unset, None, List[str]] = UNSET,
    sort_order: Union[Unset, None, List[SortOrder]] = UNSET,
    genres: Union[Unset, None, List[str]] = UNSET,
    genre_ids: Union[Unset, None, List[str]] = UNSET,
    enable_images: Union[Unset, None, bool] = UNSET,
    image_type_limit: Union[Unset, None, int] = UNSET,
    enable_image_types: Union[Unset, None, List[ImageType]] = UNSET,
    enable_user_data: Union[Unset, None, bool] = UNSET,
    series_timer_id: Union[Unset, None, str] = UNSET,
    library_series_id: Union[Unset, None, str] = UNSET,
    fields: Union[Unset, None, List[ItemFields]] = UNSET,
    enable_total_record_count: Union[Unset, None, bool] = True,
) -> Response[Union[Any, BaseItemDtoQueryResult]]:
    """Gets available live tv epgs.

    Args:
        channel_ids (Union[Unset, None, List[str]]):
        user_id (Union[Unset, None, str]):
        min_start_date (Union[Unset, None, datetime.datetime]):
        has_aired (Union[Unset, None, bool]):
        is_airing (Union[Unset, None, bool]):
        max_start_date (Union[Unset, None, datetime.datetime]):
        min_end_date (Union[Unset, None, datetime.datetime]):
        max_end_date (Union[Unset, None, datetime.datetime]):
        is_movie (Union[Unset, None, bool]):
        is_series (Union[Unset, None, bool]):
        is_news (Union[Unset, None, bool]):
        is_kids (Union[Unset, None, bool]):
        is_sports (Union[Unset, None, bool]):
        start_index (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        sort_by (Union[Unset, None, List[str]]):
        sort_order (Union[Unset, None, List[SortOrder]]):
        genres (Union[Unset, None, List[str]]):
        genre_ids (Union[Unset, None, List[str]]):
        enable_images (Union[Unset, None, bool]):
        image_type_limit (Union[Unset, None, int]):
        enable_image_types (Union[Unset, None, List[ImageType]]):
        enable_user_data (Union[Unset, None, bool]):
        series_timer_id (Union[Unset, None, str]):
        library_series_id (Union[Unset, None, str]):
        fields (Union[Unset, None, List[ItemFields]]):
        enable_total_record_count (Union[Unset, None, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, BaseItemDtoQueryResult]]
    """

    kwargs = _get_kwargs(
        channel_ids=channel_ids,
        user_id=user_id,
        min_start_date=min_start_date,
        has_aired=has_aired,
        is_airing=is_airing,
        max_start_date=max_start_date,
        min_end_date=min_end_date,
        max_end_date=max_end_date,
        is_movie=is_movie,
        is_series=is_series,
        is_news=is_news,
        is_kids=is_kids,
        is_sports=is_sports,
        start_index=start_index,
        limit=limit,
        sort_by=sort_by,
        sort_order=sort_order,
        genres=genres,
        genre_ids=genre_ids,
        enable_images=enable_images,
        image_type_limit=image_type_limit,
        enable_image_types=enable_image_types,
        enable_user_data=enable_user_data,
        series_timer_id=series_timer_id,
        library_series_id=library_series_id,
        fields=fields,
        enable_total_record_count=enable_total_record_count,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
    channel_ids: Union[Unset, None, List[str]] = UNSET,
    user_id: Union[Unset, None, str] = UNSET,
    min_start_date: Union[Unset, None, datetime.datetime] = UNSET,
    has_aired: Union[Unset, None, bool] = UNSET,
    is_airing: Union[Unset, None, bool] = UNSET,
    max_start_date: Union[Unset, None, datetime.datetime] = UNSET,
    min_end_date: Union[Unset, None, datetime.datetime] = UNSET,
    max_end_date: Union[Unset, None, datetime.datetime] = UNSET,
    is_movie: Union[Unset, None, bool] = UNSET,
    is_series: Union[Unset, None, bool] = UNSET,
    is_news: Union[Unset, None, bool] = UNSET,
    is_kids: Union[Unset, None, bool] = UNSET,
    is_sports: Union[Unset, None, bool] = UNSET,
    start_index: Union[Unset, None, int] = UNSET,
    limit: Union[Unset, None, int] = UNSET,
    sort_by: Union[Unset, None, List[str]] = UNSET,
    sort_order: Union[Unset, None, List[SortOrder]] = UNSET,
    genres: Union[Unset, None, List[str]] = UNSET,
    genre_ids: Union[Unset, None, List[str]] = UNSET,
    enable_images: Union[Unset, None, bool] = UNSET,
    image_type_limit: Union[Unset, None, int] = UNSET,
    enable_image_types: Union[Unset, None, List[ImageType]] = UNSET,
    enable_user_data: Union[Unset, None, bool] = UNSET,
    series_timer_id: Union[Unset, None, str] = UNSET,
    library_series_id: Union[Unset, None, str] = UNSET,
    fields: Union[Unset, None, List[ItemFields]] = UNSET,
    enable_total_record_count: Union[Unset, None, bool] = True,
) -> Optional[Union[Any, BaseItemDtoQueryResult]]:
    """Gets available live tv epgs.

    Args:
        channel_ids (Union[Unset, None, List[str]]):
        user_id (Union[Unset, None, str]):
        min_start_date (Union[Unset, None, datetime.datetime]):
        has_aired (Union[Unset, None, bool]):
        is_airing (Union[Unset, None, bool]):
        max_start_date (Union[Unset, None, datetime.datetime]):
        min_end_date (Union[Unset, None, datetime.datetime]):
        max_end_date (Union[Unset, None, datetime.datetime]):
        is_movie (Union[Unset, None, bool]):
        is_series (Union[Unset, None, bool]):
        is_news (Union[Unset, None, bool]):
        is_kids (Union[Unset, None, bool]):
        is_sports (Union[Unset, None, bool]):
        start_index (Union[Unset, None, int]):
        limit (Union[Unset, None, int]):
        sort_by (Union[Unset, None, List[str]]):
        sort_order (Union[Unset, None, List[SortOrder]]):
        genres (Union[Unset, None, List[str]]):
        genre_ids (Union[Unset, None, List[str]]):
        enable_images (Union[Unset, None, bool]):
        image_type_limit (Union[Unset, None, int]):
        enable_image_types (Union[Unset, None, List[ImageType]]):
        enable_user_data (Union[Unset, None, bool]):
        series_timer_id (Union[Unset, None, str]):
        library_series_id (Union[Unset, None, str]):
        fields (Union[Unset, None, List[ItemFields]]):
        enable_total_record_count (Union[Unset, None, bool]):  Default: True.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, BaseItemDtoQueryResult]
    """

    return (
        await asyncio_detailed(
            client=client,
            channel_ids=channel_ids,
            user_id=user_id,
            min_start_date=min_start_date,
            has_aired=has_aired,
            is_airing=is_airing,
            max_start_date=max_start_date,
            min_end_date=min_end_date,
            max_end_date=max_end_date,
            is_movie=is_movie,
            is_series=is_series,
            is_news=is_news,
            is_kids=is_kids,
            is_sports=is_sports,
            start_index=start_index,
            limit=limit,
            sort_by=sort_by,
            sort_order=sort_order,
            genres=genres,
            genre_ids=genre_ids,
            enable_images=enable_images,
            image_type_limit=image_type_limit,
            enable_image_types=enable_image_types,
            enable_user_data=enable_user_data,
            series_timer_id=series_timer_id,
            library_series_id=library_series_id,
            fields=fields,
            enable_total_record_count=enable_total_record_count,
        )
    ).parsed



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.header_match_type import HeaderMatchType
from ..types import UNSET, Unset

T = TypeVar("T", bound="HttpHeaderInfo")


@_attrs_define
class HttpHeaderInfo:
    """
    Attributes:
        name (Union[Unset, None, str]):
        value (Union[Unset, None, str]):
        match (Union[Unset, HeaderMatchType]):
    """

    name: Union[Unset, None, str] = UNSET
    value: Union[Unset, None, str] = UNSET
    match: Union[Unset, HeaderMatchType] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        value = self.value
        match: Union[Unset, str] = UNSET
        if not isinstance(self.match, Unset):
            match = self.match.value

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["Name"] = name
        if value is not UNSET:
            field_dict["Value"] = value
        if match is not UNSET:
            field_dict["Match"] = match

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("Name", UNSET)

        value = d.pop("Value", UNSET)

        _match = d.pop("Match", UNSET)
        match: Union[Unset, HeaderMatchType]
        if isinstance(_match, Unset):
            match = UNSET
        else:
            match = HeaderMatchType(_match)

        http_header_info = cls(
            name=name,
            value=value,
            match=match,
        )

        return http_header_info



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="SpecialViewOptionDto")


@_attrs_define
class SpecialViewOptionDto:
    """Special view option dto.

    Attributes:
        name (Union[Unset, None, str]): Gets or sets view option name.
        id (Union[Unset, None, str]): Gets or sets view option id.
    """

    name: Union[Unset, None, str] = UNSET
    id: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        name = self.name
        id = self.id

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if name is not UNSET:
            field_dict["Name"] = name
        if id is not UNSET:
            field_dict["Id"] = id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        name = d.pop("Name", UNSET)

        id = d.pop("Id", UNSET)

        special_view_option_dto = cls(
            name=name,
            id=id,
        )

        return special_view_option_dto



from enum import Enum


class RecordingStatus(str, Enum):
    CANCELLED = "Cancelled"
    COMPLETED = "Completed"
    CONFLICTEDNOTOK = "ConflictedNotOk"
    CONFLICTEDOK = "ConflictedOk"
    ERROR = "Error"
    INPROGRESS = "InProgress"
    NEW = "New"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="PinRedeemResult")


@_attrs_define
class PinRedeemResult:
    """
    Attributes:
        success (Union[Unset, bool]): Gets or sets a value indicating whether this
            MediaBrowser.Model.Users.PinRedeemResult is success.
        users_reset (Union[Unset, List[str]]): Gets or sets the users reset.
    """

    success: Union[Unset, bool] = UNSET
    users_reset: Union[Unset, List[str]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        success = self.success
        users_reset: Union[Unset, List[str]] = UNSET
        if not isinstance(self.users_reset, Unset):
            users_reset = self.users_reset

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if success is not UNSET:
            field_dict["Success"] = success
        if users_reset is not UNSET:
            field_dict["UsersReset"] = users_reset

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        success = d.pop("Success", UNSET)

        users_reset = cast(List[str], d.pop("UsersReset", UNSET))

        pin_redeem_result = cls(
            success=success,
            users_reset=users_reset,
        )

        return pin_redeem_result



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.subtitle_delivery_method import SubtitleDeliveryMethod
from ..types import UNSET, Unset

T = TypeVar("T", bound="SubtitleProfile")


@_attrs_define
class SubtitleProfile:
    """
    Attributes:
        format_ (Union[Unset, None, str]):
        method (Union[Unset, SubtitleDeliveryMethod]): Delivery method to use during playback of a specific subtitle
            format.
        didl_mode (Union[Unset, None, str]):
        language (Union[Unset, None, str]):
        container (Union[Unset, None, str]):
    """

    format_: Union[Unset, None, str] = UNSET
    method: Union[Unset, SubtitleDeliveryMethod] = UNSET
    didl_mode: Union[Unset, None, str] = UNSET
    language: Union[Unset, None, str] = UNSET
    container: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        format_ = self.format_
        method: Union[Unset, str] = UNSET
        if not isinstance(self.method, Unset):
            method = self.method.value

        didl_mode = self.didl_mode
        language = self.language
        container = self.container

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if format_ is not UNSET:
            field_dict["Format"] = format_
        if method is not UNSET:
            field_dict["Method"] = method
        if didl_mode is not UNSET:
            field_dict["DidlMode"] = didl_mode
        if language is not UNSET:
            field_dict["Language"] = language
        if container is not UNSET:
            field_dict["Container"] = container

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        format_ = d.pop("Format", UNSET)

        _method = d.pop("Method", UNSET)
        method: Union[Unset, SubtitleDeliveryMethod]
        if isinstance(_method, Unset):
            method = UNSET
        else:
            method = SubtitleDeliveryMethod(_method)

        didl_mode = d.pop("DidlMode", UNSET)

        language = d.pop("Language", UNSET)

        container = d.pop("Container", UNSET)

        subtitle_profile = cls(
            format_=format_,
            method=method,
            didl_mode=didl_mode,
            language=language,
            container=container,
        )

        return subtitle_profile



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.search_hint import SearchHint


T = TypeVar("T", bound="SearchHintResult")


@_attrs_define
class SearchHintResult:
    """Class SearchHintResult.

    Attributes:
        search_hints (Union[Unset, List['SearchHint']]): Gets the search hints.
        total_record_count (Union[Unset, int]): Gets the total record count.
    """

    search_hints: Union[Unset, List["SearchHint"]] = UNSET
    total_record_count: Union[Unset, int] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        search_hints: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.search_hints, Unset):
            search_hints = []
            for search_hints_item_data in self.search_hints:
                search_hints_item = search_hints_item_data.to_dict()

                search_hints.append(search_hints_item)

        total_record_count = self.total_record_count

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if search_hints is not UNSET:
            field_dict["SearchHints"] = search_hints
        if total_record_count is not UNSET:
            field_dict["TotalRecordCount"] = total_record_count

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.search_hint import SearchHint

        d = src_dict.copy()
        search_hints = []
        _search_hints = d.pop("SearchHints", UNSET)
        for search_hints_item_data in _search_hints or []:
            search_hints_item = SearchHint.from_dict(search_hints_item_data)

            search_hints.append(search_hints_item)

        total_record_count = d.pop("TotalRecordCount", UNSET)

        search_hint_result = cls(
            search_hints=search_hints,
            total_record_count=total_record_count,
        )

        return search_hint_result



from enum import Enum


class DlnaProfileType(str, Enum):
    AUDIO = "Audio"
    PHOTO = "Photo"
    SUBTITLE = "Subtitle"
    VIDEO = "Video"

    def __str__(self) -> str:
        return str(self.value)



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.media_update_info_path_dto import MediaUpdateInfoPathDto


T = TypeVar("T", bound="MediaUpdateInfoDto")


@_attrs_define
class MediaUpdateInfoDto:
    """Media Update Info Dto.

    Attributes:
        updates (Union[Unset, List['MediaUpdateInfoPathDto']]): Gets or sets the list of updates.
    """

    updates: Union[Unset, List["MediaUpdateInfoPathDto"]] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        updates: Union[Unset, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.updates, Unset):
            updates = []
            for updates_item_data in self.updates:
                updates_item = updates_item_data.to_dict()

                updates.append(updates_item)

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if updates is not UNSET:
            field_dict["Updates"] = updates

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.media_update_info_path_dto import MediaUpdateInfoPathDto

        d = src_dict.copy()
        updates = []
        _updates = d.pop("Updates", UNSET)
        for updates_item_data in _updates or []:
            updates_item = MediaUpdateInfoPathDto.from_dict(updates_item_data)

            updates.append(updates_item)

        media_update_info_dto = cls(
            updates=updates,
        )

        return media_update_info_dto



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="RemoveFromPlaylistRequestDto")


@_attrs_define
class RemoveFromPlaylistRequestDto:
    """Class RemoveFromPlaylistRequestDto.

    Attributes:
        playlist_item_ids (Union[Unset, List[str]]): Gets or sets the playlist identifiers ot the items. Ignored when
            clearing the playlist.
        clear_playlist (Union[Unset, bool]): Gets or sets a value indicating whether the entire playlist should be
            cleared.
        clear_playing_item (Union[Unset, bool]): Gets or sets a value indicating whether the playing item should be
            removed as well. Used only when clearing the playlist.
    """

    playlist_item_ids: Union[Unset, List[str]] = UNSET
    clear_playlist: Union[Unset, bool] = UNSET
    clear_playing_item: Union[Unset, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        playlist_item_ids: Union[Unset, List[str]] = UNSET
        if not isinstance(self.playlist_item_ids, Unset):
            playlist_item_ids = self.playlist_item_ids

        clear_playlist = self.clear_playlist
        clear_playing_item = self.clear_playing_item

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if playlist_item_ids is not UNSET:
            field_dict["PlaylistItemIds"] = playlist_item_ids
        if clear_playlist is not UNSET:
            field_dict["ClearPlaylist"] = clear_playlist
        if clear_playing_item is not UNSET:
            field_dict["ClearPlayingItem"] = clear_playing_item

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        playlist_item_ids = cast(List[str], d.pop("PlaylistItemIds", UNSET))

        clear_playlist = d.pop("ClearPlaylist", UNSET)

        clear_playing_item = d.pop("ClearPlayingItem", UNSET)

        remove_from_playlist_request_dto = cls(
            playlist_item_ids=playlist_item_ids,
            clear_playlist=clear_playlist,
            clear_playing_item=clear_playing_item,
        )

        return remove_from_playlist_request_dto



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="DeviceOptionsDto")


@_attrs_define
class DeviceOptionsDto:
    """A dto representing custom options for a device.

    Attributes:
        id (Union[Unset, int]): Gets or sets the id.
        device_id (Union[Unset, None, str]): Gets or sets the device id.
        custom_name (Union[Unset, None, str]): Gets or sets the custom name.
    """

    id: Union[Unset, int] = UNSET
    device_id: Union[Unset, None, str] = UNSET
    custom_name: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        device_id = self.device_id
        custom_name = self.custom_name

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if id is not UNSET:
            field_dict["Id"] = id
        if device_id is not UNSET:
            field_dict["DeviceId"] = device_id
        if custom_name is not UNSET:
            field_dict["CustomName"] = custom_name

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("Id", UNSET)

        device_id = d.pop("DeviceId", UNSET)

        custom_name = d.pop("CustomName", UNSET)

        device_options_dto = cls(
            id=id,
            device_id=device_id,
            custom_name=custom_name,
        )

        return device_options_dto



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="TimerEventInfo")


@_attrs_define
class TimerEventInfo:
    """
    Attributes:
        id (Union[Unset, str]):
        program_id (Union[Unset, None, str]):
    """

    id: Union[Unset, str] = UNSET
    program_id: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        program_id = self.program_id

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if id is not UNSET:
            field_dict["Id"] = id
        if program_id is not UNSET:
            field_dict["ProgramId"] = program_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("Id", UNSET)

        program_id = d.pop("ProgramId", UNSET)

        timer_event_info = cls(
            id=id,
            program_id=program_id,
        )

        return timer_event_info



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..models.play_command import PlayCommand
from ..types import UNSET, Unset

T = TypeVar("T", bound="PlayRequest")


@_attrs_define
class PlayRequest:
    """Class PlayRequest.

    Attributes:
        item_ids (Union[Unset, None, List[str]]): Gets or sets the item ids.
        start_position_ticks (Union[Unset, None, int]): Gets or sets the start position ticks that the first item should
            be played at.
        play_command (Union[Unset, PlayCommand]): Enum PlayCommand.
        controlling_user_id (Union[Unset, str]): Gets or sets the controlling user identifier.
        subtitle_stream_index (Union[Unset, None, int]):
        audio_stream_index (Union[Unset, None, int]):
        media_source_id (Union[Unset, None, str]):
        start_index (Union[Unset, None, int]):
    """

    item_ids: Union[Unset, None, List[str]] = UNSET
    start_position_ticks: Union[Unset, None, int] = UNSET
    play_command: Union[Unset, PlayCommand] = UNSET
    controlling_user_id: Union[Unset, str] = UNSET
    subtitle_stream_index: Union[Unset, None, int] = UNSET
    audio_stream_index: Union[Unset, None, int] = UNSET
    media_source_id: Union[Unset, None, str] = UNSET
    start_index: Union[Unset, None, int] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        item_ids: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.item_ids, Unset):
            if self.item_ids is None:
                item_ids = None
            else:
                item_ids = self.item_ids

        start_position_ticks = self.start_position_ticks
        play_command: Union[Unset, str] = UNSET
        if not isinstance(self.play_command, Unset):
            play_command = self.play_command.value

        controlling_user_id = self.controlling_user_id
        subtitle_stream_index = self.subtitle_stream_index
        audio_stream_index = self.audio_stream_index
        media_source_id = self.media_source_id
        start_index = self.start_index

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if item_ids is not UNSET:
            field_dict["ItemIds"] = item_ids
        if start_position_ticks is not UNSET:
            field_dict["StartPositionTicks"] = start_position_ticks
        if play_command is not UNSET:
            field_dict["PlayCommand"] = play_command
        if controlling_user_id is not UNSET:
            field_dict["ControllingUserId"] = controlling_user_id
        if subtitle_stream_index is not UNSET:
            field_dict["SubtitleStreamIndex"] = subtitle_stream_index
        if audio_stream_index is not UNSET:
            field_dict["AudioStreamIndex"] = audio_stream_index
        if media_source_id is not UNSET:
            field_dict["MediaSourceId"] = media_source_id
        if start_index is not UNSET:
            field_dict["StartIndex"] = start_index

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        item_ids = cast(List[str], d.pop("ItemIds", UNSET))

        start_position_ticks = d.pop("StartPositionTicks", UNSET)

        _play_command = d.pop("PlayCommand", UNSET)
        play_command: Union[Unset, PlayCommand]
        if isinstance(_play_command, Unset):
            play_command = UNSET
        else:
            play_command = PlayCommand(_play_command)

        controlling_user_id = d.pop("ControllingUserId", UNSET)

        subtitle_stream_index = d.pop("SubtitleStreamIndex", UNSET)

        audio_stream_index = d.pop("AudioStreamIndex", UNSET)

        media_source_id = d.pop("MediaSourceId", UNSET)

        start_index = d.pop("StartIndex", UNSET)

        play_request = cls(
            item_ids=item_ids,
            start_position_ticks=start_position_ticks,
            play_command=play_command,
            controlling_user_id=controlling_user_id,
            subtitle_stream_index=subtitle_stream_index,
            audio_stream_index=audio_stream_index,
            media_source_id=media_source_id,
            start_index=start_index,
        )

        return play_request



from enum import Enum


class PlayMethod(str, Enum):
    DIRECTPLAY = "DirectPlay"
    DIRECTSTREAM = "DirectStream"
    TRANSCODE = "Transcode"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Type, TypeVar

from attrs import define as _attrs_define

T = TypeVar("T", bound="StartupRemoteAccessDto")


@_attrs_define
class StartupRemoteAccessDto:
    """Startup remote access dto.

    Attributes:
        enable_remote_access (bool): Gets or sets a value indicating whether enable remote access.
        enable_automatic_port_mapping (bool): Gets or sets a value indicating whether enable automatic port mapping.
    """

    enable_remote_access: bool
    enable_automatic_port_mapping: bool

    def to_dict(self) -> Dict[str, Any]:
        enable_remote_access = self.enable_remote_access
        enable_automatic_port_mapping = self.enable_automatic_port_mapping

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "EnableRemoteAccess": enable_remote_access,
                "EnableAutomaticPortMapping": enable_automatic_port_mapping,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        enable_remote_access = d.pop("EnableRemoteAccess")

        enable_automatic_port_mapping = d.pop("EnableAutomaticPortMapping")

        startup_remote_access_dto = cls(
            enable_remote_access=enable_remote_access,
            enable_automatic_port_mapping=enable_automatic_port_mapping,
        )

        return startup_remote_access_dto



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="MessageCommand")


@_attrs_define
class MessageCommand:
    """
    Attributes:
        text (str):
        header (Union[Unset, None, str]):
        timeout_ms (Union[Unset, None, int]):
    """

    text: str
    header: Union[Unset, None, str] = UNSET
    timeout_ms: Union[Unset, None, int] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        text = self.text
        header = self.header
        timeout_ms = self.timeout_ms

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "Text": text,
            }
        )
        if header is not UNSET:
            field_dict["Header"] = header
        if timeout_ms is not UNSET:
            field_dict["TimeoutMs"] = timeout_ms

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        text = d.pop("Text")

        header = d.pop("Header", UNSET)

        timeout_ms = d.pop("TimeoutMs", UNSET)

        message_command = cls(
            text=text,
            header=header,
            timeout_ms=timeout_ms,
        )

        return message_command



from enum import Enum


class ItemFilter(str, Enum):
    DISLIKES = "Dislikes"
    ISFAVORITE = "IsFavorite"
    ISFAVORITEORLIKES = "IsFavoriteOrLikes"
    ISFOLDER = "IsFolder"
    ISNOTFOLDER = "IsNotFolder"
    ISPLAYED = "IsPlayed"
    ISRESUMABLE = "IsResumable"
    ISUNPLAYED = "IsUnplayed"
    LIKES = "Likes"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define

from ..models.group_queue_mode import GroupQueueMode
from ..types import UNSET, Unset

T = TypeVar("T", bound="QueueRequestDto")


@_attrs_define
class QueueRequestDto:
    """Class QueueRequestDto.

    Attributes:
        item_ids (Union[Unset, List[str]]): Gets or sets the items to enqueue.
        mode (Union[Unset, GroupQueueMode]): Enum GroupQueueMode.
    """

    item_ids: Union[Unset, List[str]] = UNSET
    mode: Union[Unset, GroupQueueMode] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        item_ids: Union[Unset, List[str]] = UNSET
        if not isinstance(self.item_ids, Unset):
            item_ids = self.item_ids

        mode: Union[Unset, str] = UNSET
        if not isinstance(self.mode, Unset):
            mode = self.mode.value

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if item_ids is not UNSET:
            field_dict["ItemIds"] = item_ids
        if mode is not UNSET:
            field_dict["Mode"] = mode

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        item_ids = cast(List[str], d.pop("ItemIds", UNSET))

        _mode = d.pop("Mode", UNSET)
        mode: Union[Unset, GroupQueueMode]
        if isinstance(_mode, Unset):
            mode = UNSET
        else:
            mode = GroupQueueMode(_mode)

        queue_request_dto = cls(
            item_ids=item_ids,
            mode=mode,
        )

        return queue_request_dto



import datetime
from typing import Any, Dict, List, Type, TypeVar, Union, cast

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="SearchHint")


@_attrs_define
class SearchHint:
    """Class SearchHintResult.

    Attributes:
        item_id (Union[Unset, str]): Gets or sets the item id.
        id (Union[Unset, str]):
        name (Union[Unset, None, str]): Gets or sets the name.
        matched_term (Union[Unset, None, str]): Gets or sets the matched term.
        index_number (Union[Unset, None, int]): Gets or sets the index number.
        production_year (Union[Unset, None, int]): Gets or sets the production year.
        parent_index_number (Union[Unset, None, int]): Gets or sets the parent index number.
        primary_image_tag (Union[Unset, None, str]): Gets or sets the image tag.
        thumb_image_tag (Union[Unset, None, str]): Gets or sets the thumb image tag.
        thumb_image_item_id (Union[Unset, None, str]): Gets or sets the thumb image item identifier.
        backdrop_image_tag (Union[Unset, None, str]): Gets or sets the backdrop image tag.
        backdrop_image_item_id (Union[Unset, None, str]): Gets or sets the backdrop image item identifier.
        type (Union[Unset, None, str]): Gets or sets the type.
        is_folder (Union[Unset, None, bool]):
        run_time_ticks (Union[Unset, None, int]): Gets or sets the run time ticks.
        media_type (Union[Unset, None, str]): Gets or sets the type of the media.
        start_date (Union[Unset, None, datetime.datetime]):
        end_date (Union[Unset, None, datetime.datetime]):
        series (Union[Unset, None, str]): Gets or sets the series.
        status (Union[Unset, None, str]):
        album (Union[Unset, None, str]): Gets or sets the album.
        album_id (Union[Unset, str]):
        album_artist (Union[Unset, None, str]): Gets or sets the album artist.
        artists (Union[Unset, None, List[str]]): Gets or sets the artists.
        song_count (Union[Unset, None, int]): Gets or sets the song count.
        episode_count (Union[Unset, None, int]): Gets or sets the episode count.
        channel_id (Union[Unset, str]): Gets or sets the channel identifier.
        channel_name (Union[Unset, None, str]): Gets or sets the name of the channel.
        primary_image_aspect_ratio (Union[Unset, None, float]): Gets or sets the primary image aspect ratio.
    """

    item_id: Union[Unset, str] = UNSET
    id: Union[Unset, str] = UNSET
    name: Union[Unset, None, str] = UNSET
    matched_term: Union[Unset, None, str] = UNSET
    index_number: Union[Unset, None, int] = UNSET
    production_year: Union[Unset, None, int] = UNSET
    parent_index_number: Union[Unset, None, int] = UNSET
    primary_image_tag: Union[Unset, None, str] = UNSET
    thumb_image_tag: Union[Unset, None, str] = UNSET
    thumb_image_item_id: Union[Unset, None, str] = UNSET
    backdrop_image_tag: Union[Unset, None, str] = UNSET
    backdrop_image_item_id: Union[Unset, None, str] = UNSET
    type: Union[Unset, None, str] = UNSET
    is_folder: Union[Unset, None, bool] = UNSET
    run_time_ticks: Union[Unset, None, int] = UNSET
    media_type: Union[Unset, None, str] = UNSET
    start_date: Union[Unset, None, datetime.datetime] = UNSET
    end_date: Union[Unset, None, datetime.datetime] = UNSET
    series: Union[Unset, None, str] = UNSET
    status: Union[Unset, None, str] = UNSET
    album: Union[Unset, None, str] = UNSET
    album_id: Union[Unset, str] = UNSET
    album_artist: Union[Unset, None, str] = UNSET
    artists: Union[Unset, None, List[str]] = UNSET
    song_count: Union[Unset, None, int] = UNSET
    episode_count: Union[Unset, None, int] = UNSET
    channel_id: Union[Unset, str] = UNSET
    channel_name: Union[Unset, None, str] = UNSET
    primary_image_aspect_ratio: Union[Unset, None, float] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        item_id = self.item_id
        id = self.id
        name = self.name
        matched_term = self.matched_term
        index_number = self.index_number
        production_year = self.production_year
        parent_index_number = self.parent_index_number
        primary_image_tag = self.primary_image_tag
        thumb_image_tag = self.thumb_image_tag
        thumb_image_item_id = self.thumb_image_item_id
        backdrop_image_tag = self.backdrop_image_tag
        backdrop_image_item_id = self.backdrop_image_item_id
        type = self.type
        is_folder = self.is_folder
        run_time_ticks = self.run_time_ticks
        media_type = self.media_type
        start_date: Union[Unset, None, str] = UNSET
        if not isinstance(self.start_date, Unset):
            start_date = self.start_date.isoformat() if self.start_date else None

        end_date: Union[Unset, None, str] = UNSET
        if not isinstance(self.end_date, Unset):
            end_date = self.end_date.isoformat() if self.end_date else None

        series = self.series
        status = self.status
        album = self.album
        album_id = self.album_id
        album_artist = self.album_artist
        artists: Union[Unset, None, List[str]] = UNSET
        if not isinstance(self.artists, Unset):
            if self.artists is None:
                artists = None
            else:
                artists = self.artists

        song_count = self.song_count
        episode_count = self.episode_count
        channel_id = self.channel_id
        channel_name = self.channel_name
        primary_image_aspect_ratio = self.primary_image_aspect_ratio

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if item_id is not UNSET:
            field_dict["ItemId"] = item_id
        if id is not UNSET:
            field_dict["Id"] = id
        if name is not UNSET:
            field_dict["Name"] = name
        if matched_term is not UNSET:
            field_dict["MatchedTerm"] = matched_term
        if index_number is not UNSET:
            field_dict["IndexNumber"] = index_number
        if production_year is not UNSET:
            field_dict["ProductionYear"] = production_year
        if parent_index_number is not UNSET:
            field_dict["ParentIndexNumber"] = parent_index_number
        if primary_image_tag is not UNSET:
            field_dict["PrimaryImageTag"] = primary_image_tag
        if thumb_image_tag is not UNSET:
            field_dict["ThumbImageTag"] = thumb_image_tag
        if thumb_image_item_id is not UNSET:
            field_dict["ThumbImageItemId"] = thumb_image_item_id
        if backdrop_image_tag is not UNSET:
            field_dict["BackdropImageTag"] = backdrop_image_tag
        if backdrop_image_item_id is not UNSET:
            field_dict["BackdropImageItemId"] = backdrop_image_item_id
        if type is not UNSET:
            field_dict["Type"] = type
        if is_folder is not UNSET:
            field_dict["IsFolder"] = is_folder
        if run_time_ticks is not UNSET:
            field_dict["RunTimeTicks"] = run_time_ticks
        if media_type is not UNSET:
            field_dict["MediaType"] = media_type
        if start_date is not UNSET:
            field_dict["StartDate"] = start_date
        if end_date is not UNSET:
            field_dict["EndDate"] = end_date
        if series is not UNSET:
            field_dict["Series"] = series
        if status is not UNSET:
            field_dict["Status"] = status
        if album is not UNSET:
            field_dict["Album"] = album
        if album_id is not UNSET:
            field_dict["AlbumId"] = album_id
        if album_artist is not UNSET:
            field_dict["AlbumArtist"] = album_artist
        if artists is not UNSET:
            field_dict["Artists"] = artists
        if song_count is not UNSET:
            field_dict["SongCount"] = song_count
        if episode_count is not UNSET:
            field_dict["EpisodeCount"] = episode_count
        if channel_id is not UNSET:
            field_dict["ChannelId"] = channel_id
        if channel_name is not UNSET:
            field_dict["ChannelName"] = channel_name
        if primary_image_aspect_ratio is not UNSET:
            field_dict["PrimaryImageAspectRatio"] = primary_image_aspect_ratio

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        item_id = d.pop("ItemId", UNSET)

        id = d.pop("Id", UNSET)

        name = d.pop("Name", UNSET)

        matched_term = d.pop("MatchedTerm", UNSET)

        index_number = d.pop("IndexNumber", UNSET)

        production_year = d.pop("ProductionYear", UNSET)

        parent_index_number = d.pop("ParentIndexNumber", UNSET)

        primary_image_tag = d.pop("PrimaryImageTag", UNSET)

        thumb_image_tag = d.pop("ThumbImageTag", UNSET)

        thumb_image_item_id = d.pop("ThumbImageItemId", UNSET)

        backdrop_image_tag = d.pop("BackdropImageTag", UNSET)

        backdrop_image_item_id = d.pop("BackdropImageItemId", UNSET)

        type = d.pop("Type", UNSET)

        is_folder = d.pop("IsFolder", UNSET)

        run_time_ticks = d.pop("RunTimeTicks", UNSET)

        media_type = d.pop("MediaType", UNSET)

        _start_date = d.pop("StartDate", UNSET)
        start_date: Union[Unset, None, datetime.datetime]
        if _start_date is None:
            start_date = None
        elif isinstance(_start_date, Unset):
            start_date = UNSET
        else:
            start_date = isoparse(_start_date)

        _end_date = d.pop("EndDate", UNSET)
        end_date: Union[Unset, None, datetime.datetime]
        if _end_date is None:
            end_date = None
        elif isinstance(_end_date, Unset):
            end_date = UNSET
        else:
            end_date = isoparse(_end_date)

        series = d.pop("Series", UNSET)

        status = d.pop("Status", UNSET)

        album = d.pop("Album", UNSET)

        album_id = d.pop("AlbumId", UNSET)

        album_artist = d.pop("AlbumArtist", UNSET)

        artists = cast(List[str], d.pop("Artists", UNSET))

        song_count = d.pop("SongCount", UNSET)

        episode_count = d.pop("EpisodeCount", UNSET)

        channel_id = d.pop("ChannelId", UNSET)

        channel_name = d.pop("ChannelName", UNSET)

        primary_image_aspect_ratio = d.pop("PrimaryImageAspectRatio", UNSET)

        search_hint = cls(
            item_id=item_id,
            id=id,
            name=name,
            matched_term=matched_term,
            index_number=index_number,
            production_year=production_year,
            parent_index_number=parent_index_number,
            primary_image_tag=primary_image_tag,
            thumb_image_tag=thumb_image_tag,
            thumb_image_item_id=thumb_image_item_id,
            backdrop_image_tag=backdrop_image_tag,
            backdrop_image_item_id=backdrop_image_item_id,
            type=type,
            is_folder=is_folder,
            run_time_ticks=run_time_ticks,
            media_type=media_type,
            start_date=start_date,
            end_date=end_date,
            series=series,
            status=status,
            album=album,
            album_id=album_id,
            album_artist=album_artist,
            artists=artists,
            song_count=song_count,
            episode_count=episode_count,
            channel_id=channel_id,
            channel_name=channel_name,
            primary_image_aspect_ratio=primary_image_aspect_ratio,
        )

        return search_hint



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.image_type import ImageType
from ..types import UNSET, Unset

T = TypeVar("T", bound="ImageOption")


@_attrs_define
class ImageOption:
    """
    Attributes:
        type (Union[Unset, ImageType]): Enum ImageType.
        limit (Union[Unset, int]): Gets or sets the limit.
        min_width (Union[Unset, int]): Gets or sets the minimum width.
    """

    type: Union[Unset, ImageType] = UNSET
    limit: Union[Unset, int] = UNSET
    min_width: Union[Unset, int] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        limit = self.limit
        min_width = self.min_width

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if type is not UNSET:
            field_dict["Type"] = type
        if limit is not UNSET:
            field_dict["Limit"] = limit
        if min_width is not UNSET:
            field_dict["MinWidth"] = min_width

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        _type = d.pop("Type", UNSET)
        type: Union[Unset, ImageType]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = ImageType(_type)

        limit = d.pop("Limit", UNSET)

        min_width = d.pop("MinWidth", UNSET)

        image_option = cls(
            type=type,
            limit=limit,
            min_width=min_width,
        )

        return image_option



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="ServerDiscoveryInfo")


@_attrs_define
class ServerDiscoveryInfo:
    """The server discovery info model.

    Attributes:
        address (Union[Unset, str]): Gets the address.
        id (Union[Unset, str]): Gets the server identifier.
        name (Union[Unset, str]): Gets the name.
        endpoint_address (Union[Unset, None, str]): Gets the endpoint address.
    """

    address: Union[Unset, str] = UNSET
    id: Union[Unset, str] = UNSET
    name: Union[Unset, str] = UNSET
    endpoint_address: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        address = self.address
        id = self.id
        name = self.name
        endpoint_address = self.endpoint_address

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if address is not UNSET:
            field_dict["Address"] = address
        if id is not UNSET:
            field_dict["Id"] = id
        if name is not UNSET:
            field_dict["Name"] = name
        if endpoint_address is not UNSET:
            field_dict["EndpointAddress"] = endpoint_address

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        address = d.pop("Address", UNSET)

        id = d.pop("Id", UNSET)

        name = d.pop("Name", UNSET)

        endpoint_address = d.pop("EndpointAddress", UNSET)

        server_discovery_info = cls(
            address=address,
            id=id,
            name=name,
            endpoint_address=endpoint_address,
        )

        return server_discovery_info



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.image_type import ImageType
from ..models.rating_type import RatingType
from ..types import UNSET, Unset

T = TypeVar("T", bound="RemoteImageInfo")


@_attrs_define
class RemoteImageInfo:
    """Class RemoteImageInfo.

    Attributes:
        provider_name (Union[Unset, None, str]): Gets or sets the name of the provider.
        url (Union[Unset, None, str]): Gets or sets the URL.
        thumbnail_url (Union[Unset, None, str]): Gets or sets a url used for previewing a smaller version.
        height (Union[Unset, None, int]): Gets or sets the height.
        width (Union[Unset, None, int]): Gets or sets the width.
        community_rating (Union[Unset, None, float]): Gets or sets the community rating.
        vote_count (Union[Unset, None, int]): Gets or sets the vote count.
        language (Union[Unset, None, str]): Gets or sets the language.
        type (Union[Unset, ImageType]): Enum ImageType.
        rating_type (Union[Unset, RatingType]):
    """

    provider_name: Union[Unset, None, str] = UNSET
    url: Union[Unset, None, str] = UNSET
    thumbnail_url: Union[Unset, None, str] = UNSET
    height: Union[Unset, None, int] = UNSET
    width: Union[Unset, None, int] = UNSET
    community_rating: Union[Unset, None, float] = UNSET
    vote_count: Union[Unset, None, int] = UNSET
    language: Union[Unset, None, str] = UNSET
    type: Union[Unset, ImageType] = UNSET
    rating_type: Union[Unset, RatingType] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        provider_name = self.provider_name
        url = self.url
        thumbnail_url = self.thumbnail_url
        height = self.height
        width = self.width
        community_rating = self.community_rating
        vote_count = self.vote_count
        language = self.language
        type: Union[Unset, str] = UNSET
        if not isinstance(self.type, Unset):
            type = self.type.value

        rating_type: Union[Unset, str] = UNSET
        if not isinstance(self.rating_type, Unset):
            rating_type = self.rating_type.value

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if provider_name is not UNSET:
            field_dict["ProviderName"] = provider_name
        if url is not UNSET:
            field_dict["Url"] = url
        if thumbnail_url is not UNSET:
            field_dict["ThumbnailUrl"] = thumbnail_url
        if height is not UNSET:
            field_dict["Height"] = height
        if width is not UNSET:
            field_dict["Width"] = width
        if community_rating is not UNSET:
            field_dict["CommunityRating"] = community_rating
        if vote_count is not UNSET:
            field_dict["VoteCount"] = vote_count
        if language is not UNSET:
            field_dict["Language"] = language
        if type is not UNSET:
            field_dict["Type"] = type
        if rating_type is not UNSET:
            field_dict["RatingType"] = rating_type

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        provider_name = d.pop("ProviderName", UNSET)

        url = d.pop("Url", UNSET)

        thumbnail_url = d.pop("ThumbnailUrl", UNSET)

        height = d.pop("Height", UNSET)

        width = d.pop("Width", UNSET)

        community_rating = d.pop("CommunityRating", UNSET)

        vote_count = d.pop("VoteCount", UNSET)

        language = d.pop("Language", UNSET)

        _type = d.pop("Type", UNSET)
        type: Union[Unset, ImageType]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = ImageType(_type)

        _rating_type = d.pop("RatingType", UNSET)
        rating_type: Union[Unset, RatingType]
        if isinstance(_rating_type, Unset):
            rating_type = UNSET
        else:
            rating_type = RatingType(_rating_type)

        remote_image_info = cls(
            provider_name=provider_name,
            url=url,
            thumbnail_url=thumbnail_url,
            height=height,
            width=width,
            community_rating=community_rating,
            vote_count=vote_count,
            language=language,
            type=type,
            rating_type=rating_type,
        )

        return remote_image_info



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="NotificationTypeInfo")


@_attrs_define
class NotificationTypeInfo:
    """
    Attributes:
        type (Union[Unset, None, str]):
        name (Union[Unset, None, str]):
        enabled (Union[Unset, bool]):
        category (Union[Unset, None, str]):
        is_based_on_user_event (Union[Unset, bool]):
    """

    type: Union[Unset, None, str] = UNSET
    name: Union[Unset, None, str] = UNSET
    enabled: Union[Unset, bool] = UNSET
    category: Union[Unset, None, str] = UNSET
    is_based_on_user_event: Union[Unset, bool] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        type = self.type
        name = self.name
        enabled = self.enabled
        category = self.category
        is_based_on_user_event = self.is_based_on_user_event

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if type is not UNSET:
            field_dict["Type"] = type
        if name is not UNSET:
            field_dict["Name"] = name
        if enabled is not UNSET:
            field_dict["Enabled"] = enabled
        if category is not UNSET:
            field_dict["Category"] = category
        if is_based_on_user_event is not UNSET:
            field_dict["IsBasedOnUserEvent"] = is_based_on_user_event

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        type = d.pop("Type", UNSET)

        name = d.pop("Name", UNSET)

        enabled = d.pop("Enabled", UNSET)

        category = d.pop("Category", UNSET)

        is_based_on_user_event = d.pop("IsBasedOnUserEvent", UNSET)

        notification_type_info = cls(
            type=type,
            name=name,
            enabled=enabled,
            category=category,
            is_based_on_user_event=is_based_on_user_event,
        )

        return notification_type_info



import datetime
from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define
from dateutil.parser import isoparse

from ..types import UNSET, Unset

T = TypeVar("T", bound="UserItemDataDto")


@_attrs_define
class UserItemDataDto:
    """Class UserItemDataDto.

    Attributes:
        rating (Union[Unset, None, float]): Gets or sets the rating.
        played_percentage (Union[Unset, None, float]): Gets or sets the played percentage.
        unplayed_item_count (Union[Unset, None, int]): Gets or sets the unplayed item count.
        playback_position_ticks (Union[Unset, int]): Gets or sets the playback position ticks.
        play_count (Union[Unset, int]): Gets or sets the play count.
        is_favorite (Union[Unset, bool]): Gets or sets a value indicating whether this instance is favorite.
        likes (Union[Unset, None, bool]): Gets or sets a value indicating whether this
            MediaBrowser.Model.Dto.UserItemDataDto is likes.
        last_played_date (Union[Unset, None, datetime.datetime]): Gets or sets the last played date.
        played (Union[Unset, bool]): Gets or sets a value indicating whether this MediaBrowser.Model.Dto.UserItemDataDto
            is played.
        key (Union[Unset, None, str]): Gets or sets the key.
        item_id (Union[Unset, None, str]): Gets or sets the item identifier.
    """

    rating: Union[Unset, None, float] = UNSET
    played_percentage: Union[Unset, None, float] = UNSET
    unplayed_item_count: Union[Unset, None, int] = UNSET
    playback_position_ticks: Union[Unset, int] = UNSET
    play_count: Union[Unset, int] = UNSET
    is_favorite: Union[Unset, bool] = UNSET
    likes: Union[Unset, None, bool] = UNSET
    last_played_date: Union[Unset, None, datetime.datetime] = UNSET
    played: Union[Unset, bool] = UNSET
    key: Union[Unset, None, str] = UNSET
    item_id: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        rating = self.rating
        played_percentage = self.played_percentage
        unplayed_item_count = self.unplayed_item_count
        playback_position_ticks = self.playback_position_ticks
        play_count = self.play_count
        is_favorite = self.is_favorite
        likes = self.likes
        last_played_date: Union[Unset, None, str] = UNSET
        if not isinstance(self.last_played_date, Unset):
            last_played_date = self.last_played_date.isoformat() if self.last_played_date else None

        played = self.played
        key = self.key
        item_id = self.item_id

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if rating is not UNSET:
            field_dict["Rating"] = rating
        if played_percentage is not UNSET:
            field_dict["PlayedPercentage"] = played_percentage
        if unplayed_item_count is not UNSET:
            field_dict["UnplayedItemCount"] = unplayed_item_count
        if playback_position_ticks is not UNSET:
            field_dict["PlaybackPositionTicks"] = playback_position_ticks
        if play_count is not UNSET:
            field_dict["PlayCount"] = play_count
        if is_favorite is not UNSET:
            field_dict["IsFavorite"] = is_favorite
        if likes is not UNSET:
            field_dict["Likes"] = likes
        if last_played_date is not UNSET:
            field_dict["LastPlayedDate"] = last_played_date
        if played is not UNSET:
            field_dict["Played"] = played
        if key is not UNSET:
            field_dict["Key"] = key
        if item_id is not UNSET:
            field_dict["ItemId"] = item_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        rating = d.pop("Rating", UNSET)

        played_percentage = d.pop("PlayedPercentage", UNSET)

        unplayed_item_count = d.pop("UnplayedItemCount", UNSET)

        playback_position_ticks = d.pop("PlaybackPositionTicks", UNSET)

        play_count = d.pop("PlayCount", UNSET)

        is_favorite = d.pop("IsFavorite", UNSET)

        likes = d.pop("Likes", UNSET)

        _last_played_date = d.pop("LastPlayedDate", UNSET)
        last_played_date: Union[Unset, None, datetime.datetime]
        if _last_played_date is None:
            last_played_date = None
        elif isinstance(_last_played_date, Unset):
            last_played_date = UNSET
        else:
            last_played_date = isoparse(_last_played_date)

        played = d.pop("Played", UNSET)

        key = d.pop("Key", UNSET)

        item_id = d.pop("ItemId", UNSET)

        user_item_data_dto = cls(
            rating=rating,
            played_percentage=played_percentage,
            unplayed_item_count=unplayed_item_count,
            playback_position_ticks=playback_position_ticks,
            play_count=play_count,
            is_favorite=is_favorite,
            likes=likes,
            last_played_date=last_played_date,
            played=played,
            key=key,
            item_id=item_id,
        )

        return user_item_data_dto



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="StartupConfigurationDto")


@_attrs_define
class StartupConfigurationDto:
    """The startup configuration DTO.

    Attributes:
        ui_culture (Union[Unset, None, str]): Gets or sets UI language culture.
        metadata_country_code (Union[Unset, None, str]): Gets or sets the metadata country code.
        preferred_metadata_language (Union[Unset, None, str]): Gets or sets the preferred language for the metadata.
    """

    ui_culture: Union[Unset, None, str] = UNSET
    metadata_country_code: Union[Unset, None, str] = UNSET
    preferred_metadata_language: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        ui_culture = self.ui_culture
        metadata_country_code = self.metadata_country_code
        preferred_metadata_language = self.preferred_metadata_language

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if ui_culture is not UNSET:
            field_dict["UICulture"] = ui_culture
        if metadata_country_code is not UNSET:
            field_dict["MetadataCountryCode"] = metadata_country_code
        if preferred_metadata_language is not UNSET:
            field_dict["PreferredMetadataLanguage"] = preferred_metadata_language

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        ui_culture = d.pop("UICulture", UNSET)

        metadata_country_code = d.pop("MetadataCountryCode", UNSET)

        preferred_metadata_language = d.pop("PreferredMetadataLanguage", UNSET)

        startup_configuration_dto = cls(
            ui_culture=ui_culture,
            metadata_country_code=metadata_country_code,
            preferred_metadata_language=preferred_metadata_language,
        )

        return startup_configuration_dto



from enum import Enum


class SyncPlayUserAccessType(str, Enum):
    CREATEANDJOINGROUPS = "CreateAndJoinGroups"
    JOINGROUPS = "JoinGroups"
    NONE = "None"

    def __str__(self) -> str:
        return str(self.value)



from enum import Enum


class PlayCommand(str, Enum):
    PLAYINSTANTMIX = "PlayInstantMix"
    PLAYLAST = "PlayLast"
    PLAYNEXT = "PlayNext"
    PLAYNOW = "PlayNow"
    PLAYSHUFFLE = "PlayShuffle"

    def __str__(self) -> str:
        return str(self.value)



from http import HTTPStatus
from io import BytesIO
from typing import Any, Dict, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...types import File, Response


def _get_kwargs() -> Dict[str, Any]:
    pass

    return {
        "method": "get",
        "url": "/LiveTv/ListingProviders/SchedulesDirect/Countries",
    }


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, File]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = File(payload=BytesIO(response.json()))

        return response_200
    if response.status_code == HTTPStatus.UNAUTHORIZED:
        response_401 = cast(Any, None)
        return response_401
    if response.status_code == HTTPStatus.FORBIDDEN:
        response_403 = cast(Any, None)
        return response_403
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, File]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    *,
    client: AuthenticatedClient,
) -> Response[Union[Any, File]]:
    """Gets available countries.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, File]]
    """

    kwargs = _get_kwargs()

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    *,
    client: AuthenticatedClient,
) -> Optional[Union[Any, File]]:
    """Gets available countries.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, File]
    """

    return sync_detailed(
        client=client,
    ).parsed


async def asyncio_detailed(
    *,
    client: AuthenticatedClient,
) -> Response[Union[Any, File]]:
    """Gets available countries.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, File]]
    """

    kwargs = _get_kwargs()

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    *,
    client: AuthenticatedClient,
) -> Optional[Union[Any, File]]:
    """Gets available countries.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, File]
    """

    return (
        await asyncio_detailed(
            client=client,
        )
    ).parsed



from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..models.recommendation_type import RecommendationType
from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.base_item_dto import BaseItemDto


T = TypeVar("T", bound="RecommendationDto")


@_attrs_define
class RecommendationDto:
    """
    Attributes:
        items (Union[Unset, None, List['BaseItemDto']]):
        recommendation_type (Union[Unset, RecommendationType]):
        baseline_item_name (Union[Unset, None, str]):
        category_id (Union[Unset, str]):
    """

    items: Union[Unset, None, List["BaseItemDto"]] = UNSET
    recommendation_type: Union[Unset, RecommendationType] = UNSET
    baseline_item_name: Union[Unset, None, str] = UNSET
    category_id: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        items: Union[Unset, None, List[Dict[str, Any]]] = UNSET
        if not isinstance(self.items, Unset):
            if self.items is None:
                items = None
            else:
                items = []
                for items_item_data in self.items:
                    items_item = items_item_data.to_dict()

                    items.append(items_item)

        recommendation_type: Union[Unset, str] = UNSET
        if not isinstance(self.recommendation_type, Unset):
            recommendation_type = self.recommendation_type.value

        baseline_item_name = self.baseline_item_name
        category_id = self.category_id

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if items is not UNSET:
            field_dict["Items"] = items
        if recommendation_type is not UNSET:
            field_dict["RecommendationType"] = recommendation_type
        if baseline_item_name is not UNSET:
            field_dict["BaselineItemName"] = baseline_item_name
        if category_id is not UNSET:
            field_dict["CategoryId"] = category_id

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.base_item_dto import BaseItemDto

        d = src_dict.copy()
        items = []
        _items = d.pop("Items", UNSET)
        for items_item_data in _items or []:
            items_item = BaseItemDto.from_dict(items_item_data)

            items.append(items_item)

        _recommendation_type = d.pop("RecommendationType", UNSET)
        recommendation_type: Union[Unset, RecommendationType]
        if isinstance(_recommendation_type, Unset):
            recommendation_type = UNSET
        else:
            recommendation_type = RecommendationType(_recommendation_type)

        baseline_item_name = d.pop("BaselineItemName", UNSET)

        category_id = d.pop("CategoryId", UNSET)

        recommendation_dto = cls(
            items=items,
            recommendation_type=recommendation_type,
            baseline_item_name=baseline_item_name,
            category_id=category_id,
        )

        return recommendation_dto



from enum import Enum


class PlaybackErrorCode(str, Enum):
    NOCOMPATIBLESTREAM = "NoCompatibleStream"
    NOTALLOWED = "NotAllowed"
    RATELIMITEXCEEDED = "RateLimitExceeded"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, Type, TypeVar

from attrs import define as _attrs_define

T = TypeVar("T", bound="QuickConnectDto")


@_attrs_define
class QuickConnectDto:
    """The quick connect request body.

    Attributes:
        secret (str): Gets or sets the quick connect secret.
    """

    secret: str

    def to_dict(self) -> Dict[str, Any]:
        secret = self.secret

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "Secret": secret,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        secret = d.pop("Secret")

        quick_connect_dto = cls(
            secret=secret,
        )

        return quick_connect_dto



from typing import Any, Dict, Type, TypeVar, Union

from attrs import define as _attrs_define

from ..types import UNSET, Unset

T = TypeVar("T", bound="TunerHostInfo")


@_attrs_define
class TunerHostInfo:
    """
    Attributes:
        id (Union[Unset, None, str]):
        url (Union[Unset, None, str]):
        type (Union[Unset, None, str]):
        device_id (Union[Unset, None, str]):
        friendly_name (Union[Unset, None, str]):
        import_favorites_only (Union[Unset, bool]):
        allow_hw_transcoding (Union[Unset, bool]):
        enable_stream_looping (Union[Unset, bool]):
        source (Union[Unset, None, str]):
        tuner_count (Union[Unset, int]):
        user_agent (Union[Unset, None, str]):
    """

    id: Union[Unset, None, str] = UNSET
    url: Union[Unset, None, str] = UNSET
    type: Union[Unset, None, str] = UNSET
    device_id: Union[Unset, None, str] = UNSET
    friendly_name: Union[Unset, None, str] = UNSET
    import_favorites_only: Union[Unset, bool] = UNSET
    allow_hw_transcoding: Union[Unset, bool] = UNSET
    enable_stream_looping: Union[Unset, bool] = UNSET
    source: Union[Unset, None, str] = UNSET
    tuner_count: Union[Unset, int] = UNSET
    user_agent: Union[Unset, None, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        id = self.id
        url = self.url
        type = self.type
        device_id = self.device_id
        friendly_name = self.friendly_name
        import_favorites_only = self.import_favorites_only
        allow_hw_transcoding = self.allow_hw_transcoding
        enable_stream_looping = self.enable_stream_looping
        source = self.source
        tuner_count = self.tuner_count
        user_agent = self.user_agent

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if id is not UNSET:
            field_dict["Id"] = id
        if url is not UNSET:
            field_dict["Url"] = url
        if type is not UNSET:
            field_dict["Type"] = type
        if device_id is not UNSET:
            field_dict["DeviceId"] = device_id
        if friendly_name is not UNSET:
            field_dict["FriendlyName"] = friendly_name
        if import_favorites_only is not UNSET:
            field_dict["ImportFavoritesOnly"] = import_favorites_only
        if allow_hw_transcoding is not UNSET:
            field_dict["AllowHWTranscoding"] = allow_hw_transcoding
        if enable_stream_looping is not UNSET:
            field_dict["EnableStreamLooping"] = enable_stream_looping
        if source is not UNSET:
            field_dict["Source"] = source
        if tuner_count is not UNSET:
            field_dict["TunerCount"] = tuner_count
        if user_agent is not UNSET:
            field_dict["UserAgent"] = user_agent

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        id = d.pop("Id", UNSET)

        url = d.pop("Url", UNSET)

        type = d.pop("Type", UNSET)

        device_id = d.pop("DeviceId", UNSET)

        friendly_name = d.pop("FriendlyName", UNSET)

        import_favorites_only = d.pop("ImportFavoritesOnly", UNSET)

        allow_hw_transcoding = d.pop("AllowHWTranscoding", UNSET)

        enable_stream_looping = d.pop("EnableStreamLooping", UNSET)

        source = d.pop("Source", UNSET)

        tuner_count = d.pop("TunerCount", UNSET)

        user_agent = d.pop("UserAgent", UNSET)

        tuner_host_info = cls(
            id=id,
            url=url,
            type=type,
            device_id=device_id,
            friendly_name=friendly_name,
            import_favorites_only=import_favorites_only,
            allow_hw_transcoding=allow_hw_transcoding,
            enable_stream_looping=enable_stream_looping,
            source=source,
            tuner_count=tuner_count,
            user_agent=user_agent,
        )

        return tuner_host_info
